@@ -75,7 +75,7 @@ GWENHYWFAR_API
 long int GWEN_MemoryDebug_GetObjectCount(const char *name);
 
 GWENHYWFAR_API
-void GWEN_MemoryDebug_CleanUp();
+void GWEN_MemoryDebug_CleanUp(void);
 
 
 #ifdef GWEN_MEMORY_DEBUG
@@ -90,44 +90,55 @@ void GWEN_MemoryDebug_CleanUp();
 
 GWENHYWFAR_API
 uint32_t GWEN_Debug_Snprintf(char *buffer,
-                                     uint32_t size,
-                                     const char *fmt, ...);
+                             uint32_t size,
+                             const char *fmt, ...);
 
 #ifndef NO_VARIADIC_MACROS
-# define DBG_ERROR(dbg_logger, format, args...) if (1){\
-  char dbg_buffer[256]; \
-  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
-  __FILE__":%5d: " format  , __LINE__ , ## args); \
-  dbg_buffer[sizeof(dbg_buffer)-1]=0; \
- GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Error, dbg_buffer);};
+# define DBG_ERROR(dbg_logger, format, args...) {\
+ if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Error) {\
+   char dbg_buffer[300]; \
+    \
+   if (snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
+       __FILE__":%5d: " format  , __LINE__ , ## args)>0) { \
+     dbg_buffer[sizeof(dbg_buffer)-1]=(char)0; \
+     GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Error, dbg_buffer);\
+    }\
+   }\
+ };
 #else /* #ifndef NO_VARIADIC_MACROS */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void DBG_ERROR(const char *logdomain, const char *format, ...);
 #endif /* #ifndef NO_VARIADIC_MACROS */
 
 #define DBG_ERROR_ERR(dbg_logger, dbg_err) {\
- char dbg_buffer[256]; \
+ char dbg_buffer[300]; \
  char dbg_errbuff[256]; \
+ \
  GWEN_Error_ToString(dbg_err,dbg_errbuff, sizeof(dbg_errbuff)); \
  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
- __FILE__":%5d: %s" , __LINE__ , dbg_errbuff); \
-  dbg_buffer[sizeof(dbg_buffer)-1]=0; \
+          __FILE__":%5d: %s" , __LINE__ , dbg_errbuff); \
+ dbg_buffer[sizeof(dbg_buffer)-1]=0; \
  GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Error, dbg_buffer);};
 
 #ifndef NO_VARIADIC_MACROS
 # define DBG_WARN(dbg_logger, format, args...) {\
-  char dbg_buffer[256]; \
-  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
-  __FILE__":%5d: " format  , __LINE__ , ## args); \
-  dbg_buffer[sizeof(dbg_buffer)-1]=0; \
- GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Warning, dbg_buffer);};
+ if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Warning) {\
+   char dbg_buffer[300]; \
+    \
+   if (snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
+       __FILE__":%5d: " format  , __LINE__ , ## args)>0) { \
+     dbg_buffer[sizeof(dbg_buffer)-1]=(char)0; \
+     GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Warning, dbg_buffer);\
+    }\
+   }\
+ };
 #else /* #ifndef NO_VARIADIC_MACROS */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void DBG_WARN(const char *logdomain, const char *format, ...);
 #endif /* #ifndef NO_VARIADIC_MACROS */
 
 #define DBG_WARN_ERR(dbg_logger, dbg_err) {\
- char dbg_buffer[256]; \
+ char dbg_buffer[300]; \
  char dbg_errbuff[256]; \
  GWEN_Error_ToString(dbg_err,dbg_errbuff, sizeof(dbg_errbuff)); \
  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
@@ -139,19 +150,22 @@ void DBG_WARN(const char *logdomain, const char *format, ...);
 #ifndef NO_VARIADIC_MACROS
 # define DBG_NOTICE(dbg_logger, format, args...) \
  if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Notice) {\
- char dbg_buffer[256]; \
- snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
- __FILE__":%5d: " format  , __LINE__ , ## args); \
-  dbg_buffer[sizeof(dbg_buffer)-1]=0; \
- GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Notice, dbg_buffer);};
+   char dbg_buffer[300]; \
+    \
+   if (snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
+       __FILE__":%5d: " format  , __LINE__ , ## args)>0) { \
+     dbg_buffer[sizeof(dbg_buffer)-1]=(char)0; \
+     GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Notice, dbg_buffer);\
+   }\
+ };
 #else /* #ifndef NO_VARIADIC_MACROS */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void DBG_NOTICE(const char *logdomain, const char *format, ...);
 #endif /* #ifndef NO_VARIADIC_MACROS */
 
 #define DBG_NOTICE_ERR(dbg_logger, dbg_err) \
  if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Notice) {\
- char dbg_buffer[256]; \
+ char dbg_buffer[300]; \
  char dbg_errbuff[256]; \
  GWEN_Error_ToString(dbg_err,dbg_errbuff, sizeof(dbg_errbuff)); \
  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
@@ -163,19 +177,22 @@ void DBG_NOTICE(const char *logdomain, const char *format, ...);
 #ifndef NO_VARIADIC_MACROS
 # define DBG_INFO(dbg_logger, format, args...) \
  if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Info) {\
-  char dbg_buffer[256]; \
- snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
- __FILE__":%5d: " format  , __LINE__ , ## args); \
-  dbg_buffer[sizeof(dbg_buffer)-1]=0; \
- GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Info, dbg_buffer);};
+   char dbg_buffer[300]; \
+    \
+   if (snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
+       __FILE__":%5d: " format  , __LINE__ , ## args)>0) { \
+     dbg_buffer[sizeof(dbg_buffer)-1]=(char)0; \
+     GWEN_Logger_Log(dbg_logger, GWEN_LoggerLevel_Info, dbg_buffer);\
+   }\
+ };
 #else /* #ifndef NO_VARIADIC_MACROS */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void DBG_INFO(const char *logdomain, const char *format, ...);
 #endif /* #ifndef NO_VARIADIC_MACROS */
 
 #define DBG_INFO_ERR(dbg_logger, dbg_err) \
  if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Info) {\
- char dbg_buffer[256]; \
+ char dbg_buffer[300]; \
  char dbg_errbuff[256]; \
  GWEN_Error_ToString(dbg_err,dbg_errbuff, sizeof(dbg_errbuff)); \
  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
@@ -191,7 +208,7 @@ void DBG_INFO(const char *logdomain, const char *format, ...);
 # ifndef NO_VARIADIC_MACROS
 #  define DBG_DEBUG(dbg_logger, format, args...) \
  if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Debug) {\
- char dbg_buffer[256]; \
+ char dbg_buffer[300]; \
  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
  __FILE__":%5d: " format  , __LINE__ , ## args); \
   dbg_buffer[sizeof(dbg_buffer)-1]=0; \
@@ -199,7 +216,7 @@ void DBG_INFO(const char *logdomain, const char *format, ...);
 
 #  define DBG_VERBOUS(dbg_logger, format, args...) \
  if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Verbous) {\
- char dbg_buffer[256]; \
+ char dbg_buffer[300]; \
  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
  __FILE__":%5d: " format  , __LINE__ , ## args); \
   dbg_buffer[sizeof(dbg_buffer)-1]=0; \
@@ -208,7 +225,7 @@ void DBG_INFO(const char *logdomain, const char *format, ...);
 
 # define DBG_DEBUG_ERR(dbg_logger, dbg_err) \
  if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Debug) {\
- char dbg_buffer[256]; \
+ char dbg_buffer[300]; \
  char dbg_errbuff[256]; \
  GWEN_Error_ToString(dbg_err,dbg_errbuff, sizeof(dbg_errbuff)); \
  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
@@ -218,7 +235,7 @@ void DBG_INFO(const char *logdomain, const char *format, ...);
 
 # define DBG_VERBOUS_ERR(dbg_logger, dbg_err) \
  if (GWEN_Logger_GetLevel(dbg_logger)>=GWEN_LoggerLevel_Verbous) {\
- char dbg_buffer[256]; \
+ char dbg_buffer[300]; \
  char dbg_errbuff[256]; \
  GWEN_Error_ToString(dbg_err,dbg_errbuff, sizeof(dbg_errbuff)); \
  snprintf(dbg_buffer, sizeof(dbg_buffer)-1,\
@@ -241,9 +258,9 @@ void DBG_INFO(const char *logdomain, const char *format, ...);
 #endif /* DISABLE_DEBUGLOG */
 
 #ifdef NO_VARIADIC_MACROS
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void DBG_DEBUG(const char *logdomain, const char *format, ...);
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void DBG_VERBOUS(const char *logdomain, const char *format, ...);
 #endif /* #ifdef NO_VARIADIC_MACROS */
 
