@@ -54,7 +54,8 @@ GWEN_LIST2_FUNCTIONS(GWEN_PLUGIN_DESCRIPTION, GWEN_PluginDescription)
 
 
 
-GWEN_PLUGIN_DESCRIPTION *GWEN_PluginDescription_new(GWEN_XMLNODE *node){
+GWEN_PLUGIN_DESCRIPTION *GWEN_PluginDescription_new(GWEN_XMLNODE *node)
+{
   GWEN_PLUGIN_DESCRIPTION *pd;
   const char *p;
 
@@ -73,7 +74,7 @@ GWEN_PLUGIN_DESCRIPTION *GWEN_PluginDescription_new(GWEN_XMLNODE *node){
 
   p=GWEN_XMLNode_GetProperty(node, "i18n", NULL);
   if (!p) {
-    DBG_WARN(GWEN_LOGDOMAIN, "Plugin has no I18N domain, using GWEN");
+    DBG_NOTICE(GWEN_LOGDOMAIN, "Plugin has no I18N domain, using GWEN");
     p="gwenhywfar";
   }
   pd->langDomain=strdup(p);
@@ -103,7 +104,8 @@ GWEN_PLUGIN_DESCRIPTION *GWEN_PluginDescription_new(GWEN_XMLNODE *node){
 
 
 
-void GWEN_PluginDescription_free(GWEN_PLUGIN_DESCRIPTION *pd){
+void GWEN_PluginDescription_free(GWEN_PLUGIN_DESCRIPTION *pd)
+{
   if (pd) {
     assert(pd->refCount);
     if (pd->refCount==1) {
@@ -129,7 +131,8 @@ void GWEN_PluginDescription_free(GWEN_PLUGIN_DESCRIPTION *pd){
 
 
 
-void GWEN_PluginDescription_Attach(GWEN_PLUGIN_DESCRIPTION *pd) {
+void GWEN_PluginDescription_Attach(GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   assert(pd->refCount);
   pd->refCount++;
@@ -137,8 +140,8 @@ void GWEN_PluginDescription_Attach(GWEN_PLUGIN_DESCRIPTION *pd) {
 
 
 
-GWEN_PLUGIN_DESCRIPTION*
-GWEN_PluginDescription_dup(const GWEN_PLUGIN_DESCRIPTION *pd) {
+GWEN_PLUGIN_DESCRIPTION *GWEN_PluginDescription_dup(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   GWEN_PLUGIN_DESCRIPTION *np;
   const char *s;
 
@@ -149,24 +152,33 @@ GWEN_PluginDescription_dup(const GWEN_PLUGIN_DESCRIPTION *pd) {
   GWEN_LIST_INIT(GWEN_PLUGIN_DESCRIPTION, np);
 
   s=pd->fileName;
-  if (s) np->fileName=strdup(s);
+  if (s)
+    np->fileName=strdup(s);
 
   s=pd->path;
-  if (s) np->path=strdup(s);
+  if (s)
+    np->path=strdup(s);
   s=pd->name;
-  if (s) np->name=strdup(s);
+  if (s)
+    np->name=strdup(s);
   s=pd->type;
-  if (s) np->type=strdup(s);
+  if (s)
+    np->type=strdup(s);
   s=pd->langDomain;
-  if (s) np->langDomain=strdup(s);
+  if (s)
+    np->langDomain=strdup(s);
   s=pd->shortDescr;
-  if (s) np->shortDescr=strdup(s);
+  if (s)
+    np->shortDescr=strdup(s);
   s=pd->author;
-  if (s) np->author=strdup(s);
+  if (s)
+    np->author=strdup(s);
   s=pd->version;
-  if (s) np->version=strdup(s);
+  if (s)
+    np->version=strdup(s);
   s=pd->longDescr;
-  if (s) np->longDescr=strdup(s);
+  if (s)
+    np->longDescr=strdup(s);
   np->isActive=pd->isActive;
   if (pd->xmlNode)
     np->xmlNode=GWEN_XMLNode_dup(pd->xmlNode);
@@ -176,26 +188,28 @@ GWEN_PluginDescription_dup(const GWEN_PLUGIN_DESCRIPTION *pd) {
 
 
 
-GWEN_PLUGIN_DESCRIPTION*
-GWEN_PluginDescription_List2_freeAll_cb(GWEN_PLUGIN_DESCRIPTION *pd, 
-					__attribute__((unused)) void *user_data) {
+GWEN_PLUGIN_DESCRIPTION *GWEN_PluginDescription_List2_freeAll_cb(GWEN_PLUGIN_DESCRIPTION *pd,
+                                                                 __attribute__((unused)) void *user_data)
+{
   GWEN_PluginDescription_free(pd);
   return 0;
 }
 
 
 
-void GWEN_PluginDescription_List2_freeAll(GWEN_PLUGIN_DESCRIPTION_LIST2 *pdl){
+void GWEN_PluginDescription_List2_freeAll(GWEN_PLUGIN_DESCRIPTION_LIST2 *pdl)
+{
   GWEN_PluginDescription_List2_ForEach
-    (pdl,
-     GWEN_PluginDescription_List2_freeAll_cb,
-     0);
+  (pdl,
+   GWEN_PluginDescription_List2_freeAll_cb,
+   0);
   GWEN_PluginDescription_List2_free(pdl);
 }
 
 
 
-const char *GWEN_PluginDescription_GetPath(const GWEN_PLUGIN_DESCRIPTION *pd){
+const char *GWEN_PluginDescription_GetPath(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return pd->path;
 }
@@ -203,65 +217,70 @@ const char *GWEN_PluginDescription_GetPath(const GWEN_PLUGIN_DESCRIPTION *pd){
 
 
 void GWEN_PluginDescription_SetPath(GWEN_PLUGIN_DESCRIPTION *pd,
-                                    const char *s){
+                                    const char *s)
+{
   assert(pd);
   free(pd->path);
-  if (s) pd->path=strdup(s);
-  else pd->path=0;
+  if (s)
+    pd->path=strdup(s);
+  else
+    pd->path=0;
 }
 
 
 
-const char *GWEN_PluginDescription_GetName(const GWEN_PLUGIN_DESCRIPTION *pd){
+const char *GWEN_PluginDescription_GetName(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return pd->name;
 }
 
 
 
-const char *GWEN_PluginDescription_GetType(const GWEN_PLUGIN_DESCRIPTION *pd){
+const char *GWEN_PluginDescription_GetType(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return pd->type;
 }
 
 
 
-const char*
-GWEN_PluginDescription_GetShortDescr(const GWEN_PLUGIN_DESCRIPTION *pd){
+const char *GWEN_PluginDescription_GetShortDescr(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return GWEN_I18N_Translate(pd->langDomain, pd->shortDescr);
 }
 
 
 
-const char*
-GWEN_PluginDescription_GetAuthor(const GWEN_PLUGIN_DESCRIPTION *pd){
+const char *GWEN_PluginDescription_GetAuthor(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return pd->author;
 }
 
 
 
-const char*
-GWEN_PluginDescription_GetVersion(const GWEN_PLUGIN_DESCRIPTION *pd){
+const char *GWEN_PluginDescription_GetVersion(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return pd->version;
 }
 
 
 
-const char*
-GWEN_PluginDescription_GetLongDescr(const GWEN_PLUGIN_DESCRIPTION *pd){
+const char *GWEN_PluginDescription_GetLongDescr(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return GWEN_I18N_Translate(pd->langDomain, pd->longDescr);
 }
 
 
 
-int
-GWEN_PluginDescription__GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
-                                             const char *s,
-                                             GWEN_BUFFER *buf){
+int GWEN_PluginDescription__GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
+                                                 const char *s,
+                                                 GWEN_BUFFER *buf)
+{
   GWEN_XMLNODE *n;
 
   assert(pd);
@@ -272,14 +291,14 @@ GWEN_PluginDescription__GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
     n=GWEN_XMLNode_FindFirstTag(n, "text", "format", s);
     while (n) {
       if (0==GWEN_XMLNode_GetProperty(n, "lang", 0)) {
-	int rv;
+        int rv;
 
-	rv=GWEN_XMLNode_toBuffer(n, buf, GWEN_XML_FLAGS_TOLERANT_ENDTAGS);
-	if (rv) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        rv=GWEN_XMLNode_toBuffer(n, buf, GWEN_XML_FLAGS_TOLERANT_ENDTAGS);
+        if (rv) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
           return rv;
-	}
-	return 0;
+        }
+        return 0;
       }
       n=GWEN_XMLNode_FindNextTag(n, "text", "format", s);
     } /* while */
@@ -290,11 +309,11 @@ GWEN_PluginDescription__GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
 
 
 
-int
-GWEN_PluginDescription__GetLocalizedLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
-                                                      const char *s,
-                                                      const char *lang,
-                                                      GWEN_BUFFER *buf){
+int GWEN_PluginDescription__GetLocalizedLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
+                                                          const char *s,
+                                                          const char *lang,
+                                                          GWEN_BUFFER *buf)
+{
   GWEN_XMLNODE *n;
 
   assert(pd);
@@ -308,14 +327,14 @@ GWEN_PluginDescription__GetLocalizedLongDescrByFormat(const GWEN_PLUGIN_DESCRIPT
 
       fmt=GWEN_XMLNode_GetProperty(n, "format", 0);
       if (fmt && strcasecmp(fmt, s)==0) {
-	int rv;
+        int rv;
 
-	rv=GWEN_XMLNode_toBuffer(n, buf, GWEN_XML_FLAGS_TOLERANT_ENDTAGS);
-	if (rv) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        rv=GWEN_XMLNode_toBuffer(n, buf, GWEN_XML_FLAGS_TOLERANT_ENDTAGS);
+        if (rv) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
           return rv;
-	}
-	return 0;
+        }
+        return 0;
       }
       n=GWEN_XMLNode_FindNextTag(n, "text", "lang", lang);
     } /* while */
@@ -326,10 +345,11 @@ GWEN_PluginDescription__GetLocalizedLongDescrByFormat(const GWEN_PLUGIN_DESCRIPT
 
 
 
-int
-GWEN_PluginDescription_GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
-                                            const char *s,
-                                            GWEN_BUFFER *buf){
+#ifndef NO_DEPRECATED_SYMBOLS
+int GWEN_PluginDescription_GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
+                                                const char *s,
+                                                GWEN_BUFFER *buf)
+{
   GWEN_STRINGLIST *langl;
   int rv;
 
@@ -338,7 +358,7 @@ GWEN_PluginDescription_GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
     GWEN_STRINGLISTENTRY *se;
 
     se=GWEN_StringList_FirstEntry(langl);
-    while(se) {
+    while (se) {
       const char *l;
 
       l=GWEN_StringListEntry_Data(se);
@@ -365,10 +385,11 @@ GWEN_PluginDescription_GetLongDescrByFormat(const GWEN_PLUGIN_DESCRIPTION *pd,
 
   return 0;
 }
+#endif  // ifndef NO_DEPRECATED_SYMBOLS
 
 
-const char*
-GWEN_PluginDescription_GetFileName(const GWEN_PLUGIN_DESCRIPTION *pd){
+const char *GWEN_PluginDescription_GetFileName(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return pd->fileName;
 }
@@ -376,24 +397,28 @@ GWEN_PluginDescription_GetFileName(const GWEN_PLUGIN_DESCRIPTION *pd){
 
 
 void GWEN_PluginDescription_SetFileName(GWEN_PLUGIN_DESCRIPTION *pd,
-					const char *s){
+                                        const char *s)
+{
   assert(pd);
   free(pd->fileName);
-  if (s) pd->fileName=strdup(s);
-  else pd->fileName=0;
+  if (s)
+    pd->fileName=strdup(s);
+  else
+    pd->fileName=0;
 }
 
 
 
-GWEN_XMLNODE*
-GWEN_PluginDescription_GetXmlNode(const GWEN_PLUGIN_DESCRIPTION *pd){
+GWEN_XMLNODE *GWEN_PluginDescription_GetXmlNode(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return pd->xmlNode;
 }
 
 
 
-GWEN_PLUGIN_DESCRIPTION_LIST2 *GWEN_LoadPluginDescrs(const char *path) {
+GWEN_PLUGIN_DESCRIPTION_LIST2 *GWEN_LoadPluginDescrs(const char *path)
+{
   GWEN_PLUGIN_DESCRIPTION_LIST2 *pl;
 
   pl=GWEN_PluginDescription_List2_new();
@@ -408,14 +433,16 @@ GWEN_PLUGIN_DESCRIPTION_LIST2 *GWEN_LoadPluginDescrs(const char *path) {
 
 
 
-int GWEN_PluginDescription_IsActive(const GWEN_PLUGIN_DESCRIPTION *pd){
+int GWEN_PluginDescription_IsActive(const GWEN_PLUGIN_DESCRIPTION *pd)
+{
   assert(pd);
   return pd->isActive;
 }
 
 
 
-void GWEN_PluginDescription_SetIsActive(GWEN_PLUGIN_DESCRIPTION *pd, int i){
+void GWEN_PluginDescription_SetIsActive(GWEN_PLUGIN_DESCRIPTION *pd, int i)
+{
   assert(pd);
   pd->isActive=i;
 }
@@ -424,7 +451,8 @@ void GWEN_PluginDescription_SetIsActive(GWEN_PLUGIN_DESCRIPTION *pd, int i){
 
 int GWEN_LoadPluginDescrsByType(const char *path,
                                 const char *type,
-                                GWEN_PLUGIN_DESCRIPTION_LIST2 *pdl){
+                                GWEN_PLUGIN_DESCRIPTION_LIST2 *pdl)
+{
   GWEN_DIRECTORY *d;
   GWEN_BUFFER *nbuf;
   char nbuffer[64];
@@ -442,48 +470,48 @@ int GWEN_LoadPluginDescrsByType(const char *path,
   if (GWEN_Directory_Open(d, GWEN_Buffer_GetStart(nbuf))) {
     DBG_INFO(GWEN_LOGDOMAIN,
              "Path \"%s\" is not available",
-	     GWEN_Buffer_GetStart(nbuf));
+             GWEN_Buffer_GetStart(nbuf));
     GWEN_Buffer_free(nbuf);
     GWEN_Directory_free(d);
     return -1;
   }
 
-  while(!GWEN_Directory_Read(d,
-			     nbuffer,
-			     sizeof(nbuffer))) {
+  while (!GWEN_Directory_Read(d,
+                              nbuffer,
+                              sizeof(nbuffer))) {
     if (strcmp(nbuffer, ".") &&
-	strcmp(nbuffer, "..")) {
+        strcmp(nbuffer, "..")) {
       int nlen;
 
       nlen=strlen(nbuffer);
       if (nlen>3) {
-	if (strcasecmp(nbuffer+nlen-4, ".xml")==0) {
+        if (strcasecmp(nbuffer+nlen-4, ".xml")==0) {
           struct stat st;
 
-	  GWEN_Buffer_Crop(nbuf, 0, pathLen);
-	  GWEN_Buffer_SetPos(nbuf, pathLen);
-	  GWEN_Buffer_AppendByte(nbuf, GWEN_DIR_SEPARATOR);
-	  GWEN_Buffer_AppendString(nbuf, nbuffer);
+          GWEN_Buffer_Crop(nbuf, 0, pathLen);
+          GWEN_Buffer_SetPos(nbuf, pathLen);
+          GWEN_Buffer_AppendByte(nbuf, GWEN_DIR_SEPARATOR);
+          GWEN_Buffer_AppendString(nbuf, nbuffer);
 
-	  if (stat(GWEN_Buffer_GetStart(nbuf), &st)) {
-	    DBG_ERROR(GWEN_LOGDOMAIN, "stat(%s): %s",
-		      GWEN_Buffer_GetStart(nbuf),
-		      strerror(errno));
-	  }
-	  else {
-	    if (!S_ISDIR(st.st_mode)) {
+          if (stat(GWEN_Buffer_GetStart(nbuf), &st)) {
+            DBG_ERROR(GWEN_LOGDOMAIN, "stat(%s): %s",
+                      GWEN_Buffer_GetStart(nbuf),
+                      strerror(errno));
+          }
+          else {
+            if (!S_ISDIR(st.st_mode)) {
               GWEN_XMLNODE *fileNode;
 
               fileNode=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "root");
               if (GWEN_XML_ReadFile(fileNode,
-				    GWEN_Buffer_GetStart(nbuf),
+                                    GWEN_Buffer_GetStart(nbuf),
                                     GWEN_XML_FLAGS_DEFAULT |
                                     GWEN_XML_FLAGS_HANDLE_HEADERS |
                                     GWEN_XML_FLAGS_HANDLE_OPEN_HTMLTAGS)) {
                 DBG_WARN(GWEN_LOGDOMAIN,
                          "Bad file \"%s\"", GWEN_Buffer_GetStart(nbuf));
               }
-	      else {
+              else {
                 GWEN_XMLNODE *node;
                 GWEN_XMLNODE *n;
                 GWEN_STRINGLIST *langl;
@@ -497,7 +525,7 @@ int GWEN_LoadPluginDescrsByType(const char *path,
                   GWEN_STRINGLISTENTRY *se;
 
                   se=GWEN_StringList_FirstEntry(langl);
-                  while(se) {
+                  while (se) {
                     const char *l;
 
                     l=GWEN_StringListEntry_Data(se);
@@ -523,7 +551,7 @@ int GWEN_LoadPluginDescrsByType(const char *path,
                     ft=GWEN_XMLNode_GetProperty(n, "type", 0);
                     if (!ft)
                       loadIt=0;
-                    else if (strcasecmp(ft, type)!=0){
+                    else if (strcasecmp(ft, type)!=0) {
                       loadIt=0;
                     }
                   } /* if type specified */
@@ -534,11 +562,11 @@ int GWEN_LoadPluginDescrsByType(const char *path,
                     }
                     else {
                       GWEN_PluginDescription_SetFileName
-                        (pd, GWEN_Buffer_GetStart(nbuf));
+                      (pd, GWEN_Buffer_GetStart(nbuf));
                       GWEN_Buffer_Crop(nbuf, 0, pathLen);
                       GWEN_Buffer_SetPos(nbuf, pathLen);
                       GWEN_PluginDescription_SetPath
-                        (pd, GWEN_Buffer_GetStart(nbuf));
+                      (pd, GWEN_Buffer_GetStart(nbuf));
                       GWEN_PluginDescription_List2_PushBack(pdl, pd);
                     }
                   } /* if loadIt */
