@@ -43,7 +43,8 @@
 
 
 
-GWEN_STRINGLIST *GWEN_StringList_new(){
+GWEN_STRINGLIST *GWEN_StringList_new(void)
+{
   GWEN_STRINGLIST *sl;
 
   GWEN_NEW_OBJECT(GWEN_STRINGLIST, sl);
@@ -54,12 +55,13 @@ GWEN_STRINGLIST *GWEN_StringList_new(){
 
 
 
-void GWEN_StringList_free(GWEN_STRINGLIST *sl){
+void GWEN_StringList_free(GWEN_STRINGLIST *sl)
+{
   GWEN_STRINGLISTENTRY *curr, *next;
 
   if (sl) {
     curr=sl->first;
-    while(curr) {
+    while (curr) {
       next=curr->next;
       GWEN_StringListEntry_free(curr);
       curr=next;
@@ -70,21 +72,24 @@ void GWEN_StringList_free(GWEN_STRINGLIST *sl){
 
 
 
-void GWEN_StringList_SetSenseCase(GWEN_STRINGLIST *sl, int i) {
+void GWEN_StringList_SetSenseCase(GWEN_STRINGLIST *sl, int i)
+{
   assert(sl);
   sl->senseCase=i;
 }
 
 
 
-void GWEN_StringList_SetIgnoreRefCount(GWEN_STRINGLIST *sl, int i) {
+void GWEN_StringList_SetIgnoreRefCount(GWEN_STRINGLIST *sl, int i)
+{
   assert(sl);
   sl->ignoreRefCount=i;
 }
 
 
 
-GWEN_STRINGLISTENTRY *GWEN_StringListEntry_new(const char *s, int take){
+GWEN_STRINGLISTENTRY *GWEN_StringListEntry_new(const char *s, int take)
+{
   GWEN_STRINGLISTENTRY *sl;
 
   GWEN_NEW_OBJECT(GWEN_STRINGLISTENTRY, sl);
@@ -102,11 +107,12 @@ GWEN_STRINGLISTENTRY *GWEN_StringListEntry_new(const char *s, int take){
 
 
 void GWEN_StringListEntry_ReplaceString(GWEN_STRINGLISTENTRY *e,
-					const char *s,
-					int take){
+                                        const char *s,
+                                        int take)
+{
   assert(e);
   if (e->data)
-    free((void*)(e->data));
+    free((void *)(e->data));
   if (take)
     e->data=s;
   else
@@ -115,10 +121,11 @@ void GWEN_StringListEntry_ReplaceString(GWEN_STRINGLISTENTRY *e,
 
 
 
-void GWEN_StringListEntry_free(GWEN_STRINGLISTENTRY *sl){
+void GWEN_StringListEntry_free(GWEN_STRINGLISTENTRY *sl)
+{
   if (sl) {
     if (sl->data)
-      free((void*)(sl->data));
+      free((void *)(sl->data));
     GWEN_FREE_OBJECT(sl);
   }
 }
@@ -126,7 +133,8 @@ void GWEN_StringListEntry_free(GWEN_STRINGLISTENTRY *sl){
 
 
 void GWEN_StringList_AppendEntry(GWEN_STRINGLIST *sl,
-				 GWEN_STRINGLISTENTRY *se){
+                                 GWEN_STRINGLISTENTRY *se)
+{
   GWEN_STRINGLISTENTRY *curr;
 
   assert(sl);
@@ -137,7 +145,7 @@ void GWEN_StringList_AppendEntry(GWEN_STRINGLIST *sl,
     sl->first=se;
   }
   else {
-    while(curr->next) {
+    while (curr->next) {
       curr=curr->next;
     }
     curr->next=se;
@@ -147,32 +155,33 @@ void GWEN_StringList_AppendEntry(GWEN_STRINGLIST *sl,
 
 
 
-GWEN_STRINGLIST *GWEN_StringList_fromTabString(const char *s, int checkDup) {
+GWEN_STRINGLIST *GWEN_StringList_fromTabString(const char *s, int checkDup)
+{
   GWEN_STRINGLIST *sl;
 
   sl=GWEN_StringList_new();
   if (s && *s) {
-    while(*s) {
+    while (*s) {
       const char *t;
       char *tmpStr;
-  
+
       t=strchr(s, '\t');
       if (t) {
-	int len;
-  
-	len=(t-s);
-	tmpStr=(char*) malloc(len+1);
-	assert(tmpStr);
-	memmove(tmpStr, s, len);
-	tmpStr[len]=0;
-	/* add partial string, take it over */
-	GWEN_StringList_AppendString(sl, tmpStr, 1, checkDup);
-	s=t+1;
+        int len;
+
+        len=(t-s);
+        tmpStr=(char *) malloc(len+1);
+        assert(tmpStr);
+        memmove(tmpStr, s, len);
+        tmpStr[len]=0;
+        /* add partial string, take it over */
+        GWEN_StringList_AppendString(sl, tmpStr, 1, checkDup);
+        s=t+1;
       }
       else {
-	/* just add the remaining string (don't take over, copy!) */
-	GWEN_StringList_AppendString(sl, s, 0, checkDup);
-	break;
+        /* just add the remaining string (don't take over, copy!) */
+        GWEN_StringList_AppendString(sl, s, 0, checkDup);
+        break;
       }
     }
   }
@@ -183,7 +192,8 @@ GWEN_STRINGLIST *GWEN_StringList_fromTabString(const char *s, int checkDup) {
 
 
 void GWEN_StringList_RemoveEntry(GWEN_STRINGLIST *sl,
-				 GWEN_STRINGLISTENTRY *se){
+                                 GWEN_STRINGLISTENTRY *se)
+{
   GWEN_STRINGLISTENTRY *curr;
 
   assert(sl);
@@ -194,16 +204,16 @@ void GWEN_StringList_RemoveEntry(GWEN_STRINGLIST *sl,
     if (curr==se) {
       sl->first=curr->next;
       if (sl->count)
-	sl->count--;
+        sl->count--;
     }
     else {
-      while(curr->next!=se) {
-	curr=curr->next;
+      while (curr->next!=se) {
+        curr=curr->next;
       }
       if (curr) {
-	curr->next=se->next;
+        curr->next=se->next;
         if (sl->count)
-	  sl->count--;
+          sl->count--;
       }
     }
   }
@@ -211,12 +221,14 @@ void GWEN_StringList_RemoveEntry(GWEN_STRINGLIST *sl,
 
 
 
-void GWEN_StringList_Clear(GWEN_STRINGLIST *sl){
+void GWEN_StringList_Clear(GWEN_STRINGLIST *sl)
+{
   GWEN_STRINGLISTENTRY *se, *next;
 
   assert(sl);
   se=sl->first;
   sl->first=0;
+  sl->count=0;
   while (se) {
     next=se->next;
     GWEN_StringListEntry_free(se);
@@ -227,33 +239,34 @@ void GWEN_StringList_Clear(GWEN_STRINGLIST *sl){
 
 
 int GWEN_StringList_AppendString(GWEN_STRINGLIST *sl,
-				 const char *s,
-				 int take,
-				 int checkDouble){
+                                 const char *s,
+                                 int take,
+                                 int checkDouble)
+{
   GWEN_STRINGLISTENTRY *se;
 
   if (checkDouble) {
     se=sl->first;
     if (sl->senseCase) {
-      while(se) {
-	if (strcmp(se->data, s)==0) {
-	  if (take)
-	    free((char*)s);
-	  se->refCount++;
-	  return 0;
-	}
-	se=se->next;
+      while (se) {
+        if (strcmp(se->data, s)==0) {
+          if (take)
+            free((char *)s);
+          se->refCount++;
+          return 0;
+        }
+        se=se->next;
       } /* while */
     }
     else {
-      while(se) {
-	if (strcasecmp(se->data, s)==0) {
-	  if (take)
-	    free((char*)s);
-	  se->refCount++;
-	  return 0;
-	}
-	se=se->next;
+      while (se) {
+        if (strcasecmp(se->data, s)==0) {
+          if (take)
+            free((char *)s);
+          se->refCount++;
+          return 0;
+        }
+        se=se->next;
       } /* while */
     }
   } /* if checkdouble */
@@ -266,79 +279,80 @@ int GWEN_StringList_AppendString(GWEN_STRINGLIST *sl,
 
 
 int GWEN_StringList_InsertString(GWEN_STRINGLIST *sl,
-				 const char *s,
-				 int take,
-				 int checkDouble){
+                                 const char *s,
+                                 int take,
+                                 int checkDouble)
+{
   GWEN_STRINGLISTENTRY *se;
 
   if (checkDouble) {
     se=sl->first;
     if (sl->senseCase) {
-      while(se) {
-	if (strcmp(se->data, s)==0) {
-	  if (take)
-	    free((char*)s);
-	  se->refCount++;
-	  return 0;
-	}
-	se=se->next;
+      while (se) {
+        if (strcmp(se->data, s)==0) {
+          if (take)
+            free((char *)s);
+          se->refCount++;
+          return 0;
+        }
+        se=se->next;
       } /* while */
     }
     else {
-      while(se) {
-	if (strcasecmp(se->data, s)==0) {
-	  if (take)
-	    free((char*)s);
-	  se->refCount++;
-	  return 0;
-	}
-	se=se->next;
+      while (se) {
+        if (strcasecmp(se->data, s)==0) {
+          if (take)
+            free((char *)s);
+          se->refCount++;
+          return 0;
+        }
+        se=se->next;
       } /* while */
     }
   } /* if checkdouble */
   se=GWEN_StringListEntry_new(s, take);
   se->next=sl->first;
   sl->first=se;
+  sl->count++;
   return 1;
 }
 
 
 
-GWENHYWFAR_API int GWEN_StringList_RemoveString(GWEN_STRINGLIST *sl,
-                                                const char *s){
+int GWEN_StringList_RemoveString(GWEN_STRINGLIST *sl, const char *s)
+{
   GWEN_STRINGLISTENTRY *se;
 
   se=sl->first;
   if (sl->senseCase) {
-    while(se) {
+    while (se) {
       if (strcmp(se->data, s)==0) {
-	assert(se->refCount);
-	se->refCount--;
-	if (sl->ignoreRefCount)
-	  GWEN_StringList_RemoveEntry(sl, se);
-	else {
-	  if (se->refCount==0)
-	    GWEN_StringList_RemoveEntry(sl, se);
-	}
-	return 1;
+        assert(se->refCount);
+        se->refCount--;
+        if (sl->ignoreRefCount)
+          GWEN_StringList_RemoveEntry(sl, se);
+        else {
+          if (se->refCount==0)
+            GWEN_StringList_RemoveEntry(sl, se);
+        }
+        return 1;
       }
       se=se->next;
     } /* while */
     return 0;
   }
   else {
-    while(se) {
+    while (se) {
       if (strcasecmp(se->data, s)==0) {
-	assert(se->refCount);
-	se->refCount--;
-	if (sl->ignoreRefCount)
-	  GWEN_StringList_RemoveEntry(sl, se);
-	else {
-	  assert(se->refCount);
-	  if (se->refCount==0)
-	    GWEN_StringList_RemoveEntry(sl, se);
-	}
-	return 1;
+        assert(se->refCount);
+        se->refCount--;
+        if (sl->ignoreRefCount)
+          GWEN_StringList_RemoveEntry(sl, se);
+        else {
+          if (se->refCount==0)
+            GWEN_StringList_RemoveEntry(sl, se);
+        }
+        return 1;
       }
       se=se->next;
     } /* while */
@@ -348,27 +362,66 @@ GWENHYWFAR_API int GWEN_StringList_RemoveString(GWEN_STRINGLIST *sl,
 
 
 
-GWEN_STRINGLISTENTRY *GWEN_StringList_FirstEntry(const GWEN_STRINGLIST *sl){
+void GWEN_StringList_RemoveFirstString(GWEN_STRINGLIST *sl)
+{
+  GWEN_STRINGLISTENTRY *se;
+
+  assert(sl);
+  se=sl->first;
+  if (se) {
+    assert(se->refCount);
+
+    se->refCount--;
+    if (sl->ignoreRefCount)
+      GWEN_StringList_RemoveEntry(sl, se);
+    else {
+      if (se->refCount==0)
+        GWEN_StringList_RemoveEntry(sl, se);
+    }
+  }
+}
+
+
+
+GWEN_STRINGLISTENTRY *GWEN_StringList_FirstEntry(const GWEN_STRINGLIST *sl)
+{
   assert(sl);
   return sl->first;
 }
 
 
 
-GWEN_STRINGLISTENTRY *GWEN_StringListEntry_Next(const GWEN_STRINGLISTENTRY *se){
+GWEN_STRINGLISTENTRY *GWEN_StringListEntry_Next(const GWEN_STRINGLISTENTRY *se)
+{
   assert(se);
   return se->next;
 }
 
 
 
-const char *GWEN_StringListEntry_Data(const GWEN_STRINGLISTENTRY *se){
+const char *GWEN_StringListEntry_Data(const GWEN_STRINGLISTENTRY *se)
+{
   assert(se);
   return se->data;
 }
 
 
-unsigned int GWEN_StringList_Count(const GWEN_STRINGLIST *sl){
+
+void GWEN_StringListEntry_SetData(GWEN_STRINGLISTENTRY *se, const char *s)
+{
+  assert(se);
+  if (se->data)
+    free((void *)(se->data));
+  if (s)
+    se->data=strdup(s);
+  else
+    se->data=NULL;
+}
+
+
+
+unsigned int GWEN_StringList_Count(const GWEN_STRINGLIST *sl)
+{
   assert(sl);
   return sl->count;
 }
@@ -376,24 +429,25 @@ unsigned int GWEN_StringList_Count(const GWEN_STRINGLIST *sl){
 
 
 int GWEN_StringList_HasString(const GWEN_STRINGLIST *sl,
-                              const char *s){
+                              const char *s)
+{
   GWEN_STRINGLISTENTRY *se;
 
   assert(sl);
   se=sl->first;
   if (sl->senseCase) {
-    while(se) {
+    while (se) {
       if (strcmp(se->data, s)==0) {
-	return 1;
+        return 1;
       }
       se=se->next;
     } /* while */
     return 0;
   }
   else {
-    while(se) {
+    while (se) {
       if (strcasecmp(se->data, s)==0) {
-	return 1;
+        return 1;
       }
       se=se->next;
     } /* while */
@@ -403,7 +457,8 @@ int GWEN_StringList_HasString(const GWEN_STRINGLIST *sl,
 
 
 
-int GWEN_StringList_GetStringPos(const GWEN_STRINGLIST *sl, const char *s){
+int GWEN_StringList_GetStringPos(const GWEN_STRINGLIST *sl, const char *s)
+{
   GWEN_STRINGLISTENTRY *se;
   int i;
 
@@ -411,9 +466,9 @@ int GWEN_StringList_GetStringPos(const GWEN_STRINGLIST *sl, const char *s){
   se=sl->first;
   if (sl->senseCase) {
     i=0;
-    while(se) {
+    while (se) {
       if (strcmp(se->data, s)==0) {
-	return i;
+        return i;
       }
       i++;
       se=se->next;
@@ -422,9 +477,9 @@ int GWEN_StringList_GetStringPos(const GWEN_STRINGLIST *sl, const char *s){
   }
   else {
     i=0;
-    while(se) {
+    while (se) {
       if (strcasecmp(se->data, s)==0) {
-	return i;
+        return i;
       }
       i++;
       se=se->next;
@@ -435,7 +490,41 @@ int GWEN_StringList_GetStringPos(const GWEN_STRINGLIST *sl, const char *s){
 
 
 
-GWEN_STRINGLIST *GWEN_StringList_dup(const GWEN_STRINGLIST *sl){
+GWEN_STRINGLISTENTRY *GWEN_StringList_FindStringEntry(const GWEN_STRINGLIST *sl, const char *s)
+{
+  GWEN_STRINGLISTENTRY *se;
+  int i;
+
+  assert(sl);
+  se=sl->first;
+  if (sl->senseCase) {
+    i=0;
+    while (se) {
+      if (strcmp(se->data, s)==0) {
+        return se;
+      }
+      i++;
+      se=se->next;
+    } /* while */
+    return NULL;
+  }
+  else {
+    i=0;
+    while (se) {
+      if (strcasecmp(se->data, s)==0) {
+        return se;
+      }
+      i++;
+      se=se->next;
+    } /* while */
+    return NULL;
+  }
+}
+
+
+
+GWEN_STRINGLIST *GWEN_StringList_dup(const GWEN_STRINGLIST *sl)
+{
   GWEN_STRINGLISTENTRY *se;
   GWEN_STRINGLIST *newsl;
 
@@ -443,7 +532,7 @@ GWEN_STRINGLIST *GWEN_StringList_dup(const GWEN_STRINGLIST *sl){
   newsl=GWEN_StringList_new();
 
   se=sl->first;
-  while(se) {
+  while (se) {
     GWEN_STRINGLISTENTRY *newse;
 
     newse=GWEN_StringListEntry_new(se->data, 0);
@@ -455,9 +544,10 @@ GWEN_STRINGLIST *GWEN_StringList_dup(const GWEN_STRINGLIST *sl){
 }
 
 
-void *GWEN_StringList_ForEach(const GWEN_STRINGLIST *l, 
-			      void *(*func)(const char *s, void *u), 
-			      void *user_data) {
+void *GWEN_StringList_ForEach(const GWEN_STRINGLIST *l,
+                              void *(*func)(const char *s, void *u),
+                              void *user_data)
+{
   GWEN_STRINGLISTENTRY *it;
   const char *el;
   void *result = 0;
@@ -466,7 +556,7 @@ void *GWEN_StringList_ForEach(const GWEN_STRINGLIST *l,
   it = GWEN_StringList_FirstEntry(l);
   if (!it)
     return 0;
-  while(it) {
+  while (it) {
     el = GWEN_StringListEntry_Data(it);
     result = func(el, user_data);
     if (result) {
@@ -479,7 +569,8 @@ void *GWEN_StringList_ForEach(const GWEN_STRINGLIST *l,
 
 
 
-const char *GWEN_StringList_FirstString(const GWEN_STRINGLIST *l){
+const char *GWEN_StringList_FirstString(const GWEN_STRINGLIST *l)
+{
   assert(l);
   if (l->first==0)
     return 0;
@@ -488,32 +579,36 @@ const char *GWEN_StringList_FirstString(const GWEN_STRINGLIST *l){
 
 
 
-static int GWEN_StringList__compar_asc_nocase(const void *a, const void *b) {
-  const GWEN_STRINGLISTENTRY * const * pse1 = a, * const * pse2 = b;
+static int GWEN_StringList__compar_asc_nocase(const void *a, const void *b)
+{
+  const GWEN_STRINGLISTENTRY *const *pse1 = a, * const * pse2 = b;
   const GWEN_STRINGLISTENTRY *se1 = *pse1, *se2 = *pse2;
   if (se1 && se2 && se1->data && se2->data)
     return strcmp(se1->data, se2->data);
   else
     return 0;
 }
-static int GWEN_StringList__compar_desc_nocase(const void *a, const void *b) {
-  const GWEN_STRINGLISTENTRY * const * pse1 = a, * const * pse2 = b;
+static int GWEN_StringList__compar_desc_nocase(const void *a, const void *b)
+{
+  const GWEN_STRINGLISTENTRY *const *pse1 = a, * const * pse2 = b;
   const GWEN_STRINGLISTENTRY *se1 = *pse1, *se2 = *pse2;
   if (se1 && se2 && se1->data && se2->data)
     return strcmp(se2->data, se1->data);
   else
     return 0;
 }
-static int GWEN_StringList__compar_asc_case(const void *a, const void *b) {
-  const GWEN_STRINGLISTENTRY * const * pse1 = a, * const * pse2 = b;
+static int GWEN_StringList__compar_asc_case(const void *a, const void *b)
+{
+  const GWEN_STRINGLISTENTRY *const *pse1 = a, * const * pse2 = b;
   const GWEN_STRINGLISTENTRY *se1 = *pse1, *se2 = *pse2;
   if (se1 && se2 && se1->data && se2->data)
     return strcasecmp(se1->data, se2->data);
   else
     return 0;
 }
-static int GWEN_StringList__compar_desc_case(const void *a, const void *b) {
-  const GWEN_STRINGLISTENTRY * const * pse1 = a, * const * pse2 = b;
+static int GWEN_StringList__compar_desc_case(const void *a, const void *b)
+{
+  const GWEN_STRINGLISTENTRY *const *pse1 = a, * const * pse2 = b;
   const GWEN_STRINGLISTENTRY *se1 = *pse1, *se2 = *pse2;
   if (se1 && se2 && se1->data && se2->data)
     return strcasecmp(se2->data, se1->data);
@@ -521,20 +616,32 @@ static int GWEN_StringList__compar_desc_case(const void *a, const void *b) {
     return 0;
 }
 
-static int GWEN_StringList__compar_asc_int(const void *a, const void *b) {
-  const GWEN_STRINGLISTENTRY * const * pse1 = a, * const * pse2 = b;
+static int GWEN_StringList__compar_asc_int(const void *a, const void *b)
+{
+  const GWEN_STRINGLISTENTRY *const *pse1 = a, * const * pse2 = b;
   const GWEN_STRINGLISTENTRY *se1 = *pse1, *se2 = *pse2;
-  if (se1 && se2 && se1->data && se2->data)
-    return (atoi(se1->data)<atoi(se2->data));
+  if (se1 && se2 && se1->data && se2->data) {
+    int i1, i2;
+
+    i1=atoi(se1->data);
+    i2=atoi(se2->data);
+    return (i1>i2) - (i1<i2);
+  }
   else
     return 0;
 }
 
-static int GWEN_StringList__compar_desc_int(const void *a, const void *b) {
-  const GWEN_STRINGLISTENTRY * const * pse1 = a, * const * pse2 = b;
+static int GWEN_StringList__compar_desc_int(const void *a, const void *b)
+{
+  const GWEN_STRINGLISTENTRY *const *pse1 = a, * const * pse2 = b;
   const GWEN_STRINGLISTENTRY *se1 = *pse1, *se2 = *pse2;
-  if (se1 && se2 && se1->data && se2->data)
-    return (atoi(se1->data)>atoi(se2->data));
+  if (se1 && se2 && se1->data && se2->data) {
+    int i1, i2;
+
+    i1=atoi(se1->data);
+    i2=atoi(se2->data);
+    return (i2>i1) - (i2<i1);
+  }
   else
     return 0;
 }
@@ -542,58 +649,55 @@ static int GWEN_StringList__compar_desc_int(const void *a, const void *b) {
 
 
 void GWEN_StringList_Sort(GWEN_STRINGLIST *l,
-			  int ascending,
-                          GWEN_STRINGLIST_SORT_MODE sortMode) {
+                          int ascending,
+                          GWEN_STRINGLIST_SORT_MODE sortMode)
+{
   GWEN_STRINGLISTENTRY **tmpEntries;
   GWEN_STRINGLISTENTRY *sentry;
   GWEN_STRINGLISTENTRY **psentry;
 
-  if (l->count<1)
+  if (l->count<2)
     return;
 
   /* sort entries into a linear pointer list */
   tmpEntries=(GWEN_STRINGLISTENTRY **)malloc((l->count+1)*
-					    sizeof(GWEN_STRINGLISTENTRY*));
+                                             sizeof(GWEN_STRINGLISTENTRY *));
   assert(tmpEntries);
   sentry=l->first;
   psentry=tmpEntries;
-  while(sentry) {
-    GWEN_STRINGLISTENTRY *nsentry;
-
+  while (sentry) {
     *(psentry++)=sentry;
-    nsentry=sentry->next;
-    sentry->next=0;
-    sentry=nsentry;
+    sentry=sentry->next;
   } /* while */
   *psentry=0;
 
   /* sort */
-  switch(sortMode) {
+  switch (sortMode) {
   case GWEN_StringList_SortModeNoCase:
     if (ascending)
-      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY*),
-            GWEN_StringList__compar_desc_nocase);
-    else
-      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY*),
+      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY *),
             GWEN_StringList__compar_asc_nocase);
+    else
+      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY *),
+            GWEN_StringList__compar_desc_nocase);
     break;
 
   case GWEN_StringList_SortModeCase:
     if (ascending)
-      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY*),
-            GWEN_StringList__compar_desc_case);
-    else
-      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY*),
+      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY *),
             GWEN_StringList__compar_asc_case);
+    else
+      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY *),
+            GWEN_StringList__compar_desc_case);
     break;
 
   case GWEN_StringList_SortModeInt:
     if (ascending)
-      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY*),
-            GWEN_StringList__compar_desc_int);
-    else
-      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY*),
+      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY *),
             GWEN_StringList__compar_asc_int);
+    else
+      qsort(tmpEntries, l->count, sizeof(GWEN_STRINGLISTENTRY *),
+            GWEN_StringList__compar_desc_int);
     break;
 
   default:
@@ -603,8 +707,7 @@ void GWEN_StringList_Sort(GWEN_STRINGLIST *l,
   /* sort entries back into GWEN_STRINGLIST */
   psentry=tmpEntries;
   sentry=0;
-  while(*psentry) {
-    (*psentry)->next=0;
+  while (*psentry) {
     if (sentry)
       sentry->next=*psentry;
     else
@@ -612,6 +715,7 @@ void GWEN_StringList_Sort(GWEN_STRINGLIST *l,
     sentry=*psentry;
     psentry++;
   } /* while */
+  sentry->next=NULL;
 
   free(tmpEntries);
 
@@ -619,12 +723,13 @@ void GWEN_StringList_Sort(GWEN_STRINGLIST *l,
 
 
 
-const char *GWEN_StringList_StringAt(const GWEN_STRINGLIST *sl, int idx) {
+const char *GWEN_StringList_StringAt(const GWEN_STRINGLIST *sl, int idx)
+{
   GWEN_STRINGLISTENTRY *se;
 
   assert(sl);
   se=sl->first;
-  while(se) {
+  while (se) {
     if (idx--==0)
       return se->data;
     se=se->next;
@@ -634,48 +739,49 @@ const char *GWEN_StringList_StringAt(const GWEN_STRINGLIST *sl, int idx) {
 
 
 
-GWEN_STRINGLIST *GWEN_StringList_fromString(const char *str, const char *delimiters, int checkDouble) {
+GWEN_STRINGLIST *GWEN_StringList_fromString(const char *str, const char *delimiters, int checkDouble)
+{
   if (str && *str) {
     GWEN_STRINGLIST *sl;
     const unsigned char *s;
-  
+
     sl=GWEN_StringList_new();
-    s=(const unsigned char*)str;
-  
-    while(*s) {
+    s=(const unsigned char *)str;
+
+    while (*s) {
       /* skip blanks */
-      while(*s && *s<33)
-	s++;
+      while (*s && *s<33)
+        s++;
 
       if (*s) {
-	const unsigned char *pStart;
-	int len;
+        const unsigned char *pStart;
+        int len;
 
-	/* read word */
-	pStart=s;
-        s++;
-	while(*s && strchr(delimiters, *s)==NULL)
-	  s++;
-	len=s-pStart;
-    
-	if (len) {
-	  char *toAdd;
+        /* read word */
+        pStart=s;
+        //s++;
+        while (*s && strchr(delimiters, *s)==NULL)
+          s++;
+        len=s-pStart;
 
-	  toAdd=(char*) malloc(len+1);
-	  assert(toAdd);
+        if (len) {
+          char *toAdd;
 
-	  memmove(toAdd, pStart, len);
-	  toAdd[len]=0;
-    
-	  GWEN_StringList_AppendString(sl, toAdd, 1, checkDouble);
-	}
+          toAdd=(char *) malloc(len+1);
+          assert(toAdd);
+
+          memmove(toAdd, pStart, len);
+          toAdd[len]=0;
+
+          GWEN_StringList_AppendString(sl, toAdd, 1, checkDouble);
+        }
       }
 
       if (*s==0)
-	break;
+        break;
       s++;
     }
-  
+
     if (GWEN_StringList_Count(sl)==0) {
       GWEN_StringList_free(sl);
       return NULL;
