@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: crypttoken.h 1113 2007-01-10 09:14:16Z martin $
     begin       : Wed Mar 16 2005
-    copyright   : (C) 2005 by Martin Preuss
+    copyright   : (C) 2005-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -38,6 +35,10 @@ struct GWEN_CTF_CONTEXT {
 
   GWEN_CRYPT_KEY *remoteAuthKey;
   GWEN_CRYPT_TOKEN_KEYINFO *remoteAuthKeyInfo;
+
+  GWEN_CRYPT_KEY *tempLocalSignKey;
+  GWEN_CRYPT_TOKEN_KEYINFO *tempLocalSignKeyInfo;
+
 };
 
 
