@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Sun Nov 23 2003
-    copyright   : (C) 2003 by Martin Preuss
+    copyright   : (C) 2019 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -59,11 +56,31 @@
 # define DIRSEP "/"
 #endif
 
+#define DISABLE_DEBUGLOG
+
+
+
+/* ------------------------------------------------------------------------------------------------
+ * forward declarations
+ * ------------------------------------------------------------------------------------------------
+ */
+
+
+static void *GWEN_Directory_HandlePathElement(const char *entry, void *data, unsigned int flags);
+
+
+
+/* ------------------------------------------------------------------------------------------------
+ * implementations
+ * ------------------------------------------------------------------------------------------------
+ */
+
 
 
 void *GWEN_Directory_HandlePathElement(const char *entry,
                                        void *data,
-                                       unsigned int flags){
+                                       unsigned int flags)
+{
   char *p;
   struct stat st;
   int exists;
@@ -79,7 +96,7 @@ void *GWEN_Directory_HandlePathElement(const char *entry,
 
     /* append backslash if entry only consists of a drive specification */
     len=strlen(entry);
-    if ( (len==2) && (entry[1] == ':') ) {
+    if ((len==2) && (entry[1] == ':')) {
       ebuf=GWEN_Buffer_new(0, len+2, 0, 1);
       GWEN_Buffer_AppendString(ebuf, entry);
       GWEN_Buffer_AppendByte(ebuf, '\\');
@@ -95,7 +112,7 @@ void *GWEN_Directory_HandlePathElement(const char *entry,
     return 0;
   }
 
-  buf=(GWEN_BUFFER*)data;
+  buf=(GWEN_BUFFER *)data;
   if (GWEN_Buffer_GetUsedBytes(buf) && !withDrive) {
     char c;
 
@@ -112,7 +129,7 @@ void *GWEN_Directory_HandlePathElement(const char *entry,
 
   /* check for existence of the file/folder */
   p=GWEN_Buffer_GetStart(buf);
-  DBG_DEBUG(GWEN_LOGDOMAIN, "Checking path \"%s\"", p);
+  DBG_VERBOUS(GWEN_LOGDOMAIN, "Checking path \"%s\"", p);
   if (stat(p, &st)) {
     exists=0;
     DBG_DEBUG(GWEN_LOGDOMAIN, "stat: %s (%s)", strerror(errno), p);
@@ -125,19 +142,19 @@ void *GWEN_Directory_HandlePathElement(const char *entry,
     }
   }
   else {
-    DBG_DEBUG(GWEN_LOGDOMAIN, "Checking for type");
+    DBG_VERBOUS(GWEN_LOGDOMAIN, "Checking for type");
     exists=1;
     if (flags & GWEN_PATH_FLAGS_VARIABLE) {
       if (!S_ISREG(st.st_mode)) {
         DBG_INFO(GWEN_LOGDOMAIN, "%s not a regular file", p);
-	GWEN_Buffer_free(ebuf);
+        GWEN_Buffer_free(ebuf);
         return 0;
       }
     }
     else {
       if (!S_ISDIR(st.st_mode)) {
         DBG_INFO(GWEN_LOGDOMAIN, "%s not a direcory", p);
-	GWEN_Buffer_free(ebuf);
+        GWEN_Buffer_free(ebuf);
         return 0;
       }
     }
@@ -156,10 +173,10 @@ void *GWEN_Directory_HandlePathElement(const char *entry,
     DBG_DEBUG(GWEN_LOGDOMAIN, "Entry \"%s\" does not exist", p);
 
     isPublic=(
-              ((flags & GWEN_PATH_FLAGS_LAST) &&
-               (flags & GWEN_DIR_FLAGS_PUBLIC_NAME)) ||
-              (!(flags & GWEN_PATH_FLAGS_LAST) &&
-               (flags & GWEN_DIR_FLAGS_PUBLIC_PATH))
+               ((flags & GWEN_PATH_FLAGS_LAST) &&
+                (flags & GWEN_DIR_FLAGS_PUBLIC_NAME)) ||
+               (!(flags & GWEN_PATH_FLAGS_LAST) &&
+                (flags & GWEN_DIR_FLAGS_PUBLIC_PATH))
              );
 
     if (flags & GWEN_PATH_FLAGS_VARIABLE) {
@@ -168,49 +185,49 @@ void *GWEN_Directory_HandlePathElement(const char *entry,
 
       DBG_DEBUG(GWEN_LOGDOMAIN, "Creating file \"%s\"", p);
       if (isPublic)
-	fd=open(p, O_RDWR | O_CREAT | O_TRUNC,
-		S_IRUSR | S_IWUSR
+        fd=open(p, O_RDWR | O_CREAT | O_TRUNC,
+                S_IRUSR | S_IWUSR
 #ifdef S_IRGRP
-		| S_IRGRP
+                | S_IRGRP
 #endif
 #ifdef S_IROTH
-		| S_IROTH
+                | S_IROTH
 #endif
-	       );
+               );
       else
-	fd=open(p, O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
+        fd=open(p, O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
       if (fd==-1) {
         DBG_ERROR(GWEN_LOGDOMAIN, "open: %s (%s)", strerror(errno), p);
-	GWEN_Buffer_free(ebuf);
+        GWEN_Buffer_free(ebuf);
         return 0;
       }
       close(fd);
-      DBG_DEBUG(GWEN_LOGDOMAIN, "Sucessfully created");
+      DBG_VERBOUS(GWEN_LOGDOMAIN, "Successfully created");
     }
     else {
       /* create dir */
-      DBG_DEBUG(GWEN_LOGDOMAIN, "Creating folder \"%s\"", p);
+      DBG_VERBOUS(GWEN_LOGDOMAIN, "Creating folder \"%s\"", p);
 
       if (isPublic) {
-	if (GWEN_Directory_CreatePublic(p)) {
-	  DBG_ERROR(GWEN_LOGDOMAIN, "Could not create directory \"%s\"", p);
-	  GWEN_Buffer_free(ebuf);
-	  return 0;
-	}
+        if (GWEN_Directory_CreatePublic(p)) {
+          DBG_ERROR(GWEN_LOGDOMAIN, "Could not create directory \"%s\"", p);
+          GWEN_Buffer_free(ebuf);
+          return 0;
+        }
       }
       else {
-	if (GWEN_Directory_Create(p)) {
-	  DBG_ERROR(GWEN_LOGDOMAIN, "Could not create directory \"%s\"", p);
-	  GWEN_Buffer_free(ebuf);
-	  return 0;
-	}
+        if (GWEN_Directory_Create(p)) {
+          DBG_ERROR(GWEN_LOGDOMAIN, "Could not create directory \"%s\"", p);
+          GWEN_Buffer_free(ebuf);
+          return 0;
+        }
       }
     }
   } /* if exists */
   else {
-    DBG_DEBUG(GWEN_LOGDOMAIN, "Entry \"%s\" exists", p);
+    DBG_VERBOUS(GWEN_LOGDOMAIN, "Entry \"%s\" exists", p);
   }
-  DBG_DEBUG(GWEN_LOGDOMAIN, "Returning this: %s", p);
+  DBG_VERBOUS(GWEN_LOGDOMAIN, "Returning this: %s", p);
   GWEN_Buffer_free(ebuf);
   return buf;
 }
@@ -218,7 +235,8 @@ void *GWEN_Directory_HandlePathElement(const char *entry,
 
 
 int GWEN_Directory_GetPath(const char *path,
-                           unsigned int flags) {
+                           unsigned int flags)
+{
   GWEN_BUFFER *buf;
   void *p;
 
@@ -239,7 +257,11 @@ int GWEN_Directory_GetPath(const char *path,
 
 
 int GWEN_Directory_OsifyPath(const char *path, GWEN_BUFFER *pbuf,
-                             int transformDriveElement){
+#ifndef OS_WIN32
+                             GWEN_UNUSED
+#endif
+                             int transformDriveElement)
+{
   const char *p;
 
   p=path;
@@ -249,15 +271,15 @@ int GWEN_Directory_OsifyPath(const char *path, GWEN_BUFFER *pbuf,
   if (transformDriveElement) {
     if (*p=='/')
       if (isalpha(p[1]))
-	if (p[2]=='/' || p[2]==0) {
-	  GWEN_Buffer_AppendByte(pbuf, p[0]);
+        if (p[2]=='/' || p[2]==0) {
+          GWEN_Buffer_AppendByte(pbuf, p[0]);
           GWEN_Buffer_AppendByte(pbuf, ':');
           p+=2;
         }
   }
 #endif
 
-  while(*p) {
+  while (*p) {
     if (*p=='/' || *p=='\\') {
       while (*p=='/' || *p=='\\')
         p++;
@@ -280,11 +302,12 @@ int GWEN_Directory_OsifyPath(const char *path, GWEN_BUFFER *pbuf,
 
 int GWEN_Directory_FindFileInPaths(const GWEN_STRINGLIST *paths,
                                    const char *filePath,
-                                   GWEN_BUFFER *fbuf) {
+                                   GWEN_BUFFER *fbuf)
+{
   GWEN_STRINGLISTENTRY *se;
 
   se=GWEN_StringList_FirstEntry(paths);
-  while(se) {
+  while (se) {
     GWEN_BUFFER *tbuf;
     FILE *f;
 
@@ -292,15 +315,15 @@ int GWEN_Directory_FindFileInPaths(const GWEN_STRINGLIST *paths,
     GWEN_Buffer_AppendString(tbuf, GWEN_StringListEntry_Data(se));
     GWEN_Buffer_AppendString(tbuf, DIRSEP);
     GWEN_Buffer_AppendString(tbuf, filePath);
-    DBG_DEBUG(GWEN_LOGDOMAIN, "Trying \"%s\"",
-	      GWEN_Buffer_GetStart(tbuf));
+    DBG_VERBOUS(GWEN_LOGDOMAIN, "Trying \"%s\"",
+                GWEN_Buffer_GetStart(tbuf));
     f=fopen(GWEN_Buffer_GetStart(tbuf), "r");
     if (f) {
       fclose(f);
       DBG_DEBUG(GWEN_LOGDOMAIN,
-		"File \"%s\" found in folder \"%s\"",
-		filePath,
-		GWEN_StringListEntry_Data(se));
+                "File \"%s\" found in folder \"%s\"",
+                filePath,
+                GWEN_StringListEntry_Data(se));
       GWEN_Buffer_AppendBuffer(fbuf, tbuf);
       GWEN_Buffer_free(tbuf);
       return 0;
@@ -318,11 +341,12 @@ int GWEN_Directory_FindFileInPaths(const GWEN_STRINGLIST *paths,
 
 int GWEN_Directory_FindPathForFile(const GWEN_STRINGLIST *paths,
                                    const char *filePath,
-                                   GWEN_BUFFER *fbuf) {
+                                   GWEN_BUFFER *fbuf)
+{
   GWEN_STRINGLISTENTRY *se;
 
   se=GWEN_StringList_FirstEntry(paths);
-  while(se) {
+  while (se) {
     GWEN_BUFFER *tbuf;
     FILE *f;
 
@@ -330,15 +354,15 @@ int GWEN_Directory_FindPathForFile(const GWEN_STRINGLIST *paths,
     GWEN_Buffer_AppendString(tbuf, GWEN_StringListEntry_Data(se));
     GWEN_Buffer_AppendString(tbuf, DIRSEP);
     GWEN_Buffer_AppendString(tbuf, filePath);
-    DBG_DEBUG(GWEN_LOGDOMAIN, "Trying \"%s\"",
-	      GWEN_Buffer_GetStart(tbuf));
+    DBG_VERBOUS(GWEN_LOGDOMAIN, "Trying \"%s\"",
+                GWEN_Buffer_GetStart(tbuf));
     f=fopen(GWEN_Buffer_GetStart(tbuf), "r");
     if (f) {
       fclose(f);
       DBG_INFO(GWEN_LOGDOMAIN,
-	       "File \"%s\" found in folder \"%s\"",
-	       filePath,
-	       GWEN_StringListEntry_Data(se));
+               "File \"%s\" found in folder \"%s\"",
+               filePath,
+               GWEN_StringListEntry_Data(se));
       GWEN_Buffer_AppendString(fbuf, GWEN_StringListEntry_Data(se));
       GWEN_Buffer_free(tbuf);
       return 0;
@@ -360,30 +384,30 @@ int GWEN_Directory_GetTmpDirectory(char *buffer, unsigned int size)
   assert(buffer);
 
   /* Copied from http://svn.gnome.org/viewcvs/glib/trunk/glib/gutils.c */
-  tmp_dir = getenv ("TMPDIR");
+  tmp_dir = getenv("TMPDIR");
   if (!tmp_dir)
-    tmp_dir = getenv ("TMP");
+    tmp_dir = getenv("TMP");
   if (!tmp_dir)
-    tmp_dir = getenv ("TEMP");
+    tmp_dir = getenv("TEMP");
 
-  if (!tmp_dir)
-    {
+  if (!tmp_dir) {
 #ifdef OS_WIN32
-      tmp_dir = "C:\\";
-#else  
-      tmp_dir = "/tmp";
-#endif	/* !OS_WIN32 */
-    }
+    tmp_dir = "C:\\";
+#else
+    tmp_dir = "/tmp";
+#endif  /* !OS_WIN32 */
+  }
 
-  strncpy (buffer, tmp_dir, size);
+  strncpy(buffer, tmp_dir, size);
   return 0;
 }
 
 
 
 int GWEN_Directory_GetAllEntries(const char *folder,
-				 GWEN_STRINGLIST *sl,
-				 const char *mask) {
+                                 GWEN_STRINGLIST *sl,
+                                 const char *mask)
+{
   GWEN_DIRECTORY *d;
   int rv;
   char buffer[256];
@@ -396,11 +420,11 @@ int GWEN_Directory_GetAllEntries(const char *folder,
     return rv;
   }
 
-  while(0==GWEN_Directory_Read(d, buffer, sizeof(buffer))) {
+  while (0==GWEN_Directory_Read(d, buffer, sizeof(buffer))) {
     if (strcmp(buffer, ".")!=0 &&
-	strcmp(buffer, "..")!=0 &&
-	(mask==NULL ||
-	 GWEN_Text_ComparePattern(buffer+1, mask, 0)!=-1))
+        strcmp(buffer, "..")!=0 &&
+        (mask==NULL ||
+         GWEN_Text_ComparePattern(buffer+1, mask, 0)!=-1))
       GWEN_StringList_AppendString(sl, buffer, 0, 1);
   }
 
@@ -412,8 +436,9 @@ int GWEN_Directory_GetAllEntries(const char *folder,
 
 
 int GWEN_Directory_GetFileEntriesWithType(const char *folder,
-					  GWEN_STRINGLIST *sl,
-					  const char *mask) {
+                                          GWEN_STRINGLIST *sl,
+                                          const char *mask)
+{
   GWEN_DIRECTORY *d;
   int rv;
   char buffer[256];
@@ -433,22 +458,22 @@ int GWEN_Directory_GetFileEntriesWithType(const char *folder,
   GWEN_Buffer_AppendString(pbuf, GWEN_DIR_SEPARATOR_S);
   pos=GWEN_Buffer_GetPos(pbuf);
 
-  while(0==GWEN_Directory_Read(d, buffer+1, sizeof(buffer)-2)) {
+  while (0==GWEN_Directory_Read(d, buffer+1, sizeof(buffer)-2)) {
     if (strcmp(buffer, ".")!=0 &&
-	strcmp(buffer, "..")!=0 &&
-	(mask==NULL ||
-	 GWEN_Text_ComparePattern(buffer+1, mask, 0)!=-1)) {
+        strcmp(buffer, "..")!=0 &&
+        (mask==NULL ||
+         GWEN_Text_ComparePattern(buffer+1, mask, 0)!=-1)) {
       struct stat st;
 
       GWEN_Buffer_AppendString(pbuf, buffer+1);
       if (stat(GWEN_Buffer_GetStart(pbuf), &st)==0) {
-	if (S_ISREG(st.st_mode))
-	  buffer[0]='f';
-	else if (S_ISDIR(st.st_mode))
-	  buffer[0]='d';
-	else
-	  buffer[0]='?';
-	GWEN_StringList_AppendString(sl, buffer, 0, 1);
+        if (S_ISREG(st.st_mode))
+          buffer[0]='f';
+        else if (S_ISDIR(st.st_mode))
+          buffer[0]='d';
+        else
+          buffer[0]='?';
+        GWEN_StringList_AppendString(sl, buffer, 0, 1);
       }
       GWEN_Buffer_Crop(pbuf, 0, pos);
     }
@@ -463,7 +488,8 @@ int GWEN_Directory_GetFileEntriesWithType(const char *folder,
 
 
 int GWEN_Directory_GetFileEntries(const char *folder, GWEN_STRINGLIST *sl,
-				  const char *mask) {
+                                  const char *mask)
+{
   GWEN_DIRECTORY *d;
   int rv;
   char buffer[256];
@@ -483,17 +509,17 @@ int GWEN_Directory_GetFileEntries(const char *folder, GWEN_STRINGLIST *sl,
   GWEN_Buffer_AppendString(pbuf, GWEN_DIR_SEPARATOR_S);
   pos=GWEN_Buffer_GetPos(pbuf);
 
-  while(0==GWEN_Directory_Read(d, buffer, sizeof(buffer))) {
+  while (0==GWEN_Directory_Read(d, buffer, sizeof(buffer))) {
     if (strcmp(buffer, ".")!=0 &&
-	strcmp(buffer, "..")!=0 &&
-	(mask==NULL ||
-	 GWEN_Text_ComparePattern(buffer+1, mask, 0)!=-1)) {
+        strcmp(buffer, "..")!=0 &&
+        (mask==NULL ||
+         GWEN_Text_ComparePattern(buffer+1, mask, 0)!=-1)) {
       struct stat st;
 
       GWEN_Buffer_AppendString(pbuf, buffer);
       if (stat(GWEN_Buffer_GetStart(pbuf), &st)==0) {
-	if (S_ISREG(st.st_mode))
-	  GWEN_StringList_AppendString(sl, buffer, 0, 1);
+        if (S_ISREG(st.st_mode))
+          GWEN_StringList_AppendString(sl, buffer, 0, 1);
       }
       GWEN_Buffer_Crop(pbuf, 0, pos);
     }
@@ -508,7 +534,8 @@ int GWEN_Directory_GetFileEntries(const char *folder, GWEN_STRINGLIST *sl,
 
 
 int GWEN_Directory_GetDirEntries(const char *folder, GWEN_STRINGLIST *sl,
-				 const char *mask) {
+                                 const char *mask)
+{
   GWEN_DIRECTORY *d;
   int rv;
   char buffer[256];
@@ -528,17 +555,17 @@ int GWEN_Directory_GetDirEntries(const char *folder, GWEN_STRINGLIST *sl,
   GWEN_Buffer_AppendString(pbuf, GWEN_DIR_SEPARATOR_S);
   pos=GWEN_Buffer_GetPos(pbuf);
 
-  while(0==GWEN_Directory_Read(d, buffer, sizeof(buffer))) {
+  while (0==GWEN_Directory_Read(d, buffer, sizeof(buffer))) {
     if (strcmp(buffer, ".")!=0 &&
-	strcmp(buffer, "..")!=0 &&
-	(mask==NULL ||
-	 GWEN_Text_ComparePattern(buffer+1, mask, 0)!=-1)) {
+        strcmp(buffer, "..")!=0 &&
+        (mask==NULL ||
+         GWEN_Text_ComparePattern(buffer+1, mask, 0)!=-1)) {
       struct stat st;
 
       GWEN_Buffer_AppendString(pbuf, buffer);
       if (stat(GWEN_Buffer_GetStart(pbuf), &st)==0) {
-	if (S_ISDIR(st.st_mode))
-	  GWEN_StringList_AppendString(sl, buffer, 0, 1);
+        if (S_ISDIR(st.st_mode))
+          GWEN_StringList_AppendString(sl, buffer, 0, 1);
       }
       GWEN_Buffer_Crop(pbuf, 0, pos);
     }
@@ -552,8 +579,9 @@ int GWEN_Directory_GetDirEntries(const char *folder, GWEN_STRINGLIST *sl,
 
 
 int GWEN_Directory_GetMatchingFilesRecursively(const char *folder,
-					       GWEN_STRINGLIST *sl,
-					       const char *mask) {
+                                               GWEN_STRINGLIST *sl,
+                                               const char *mask)
+{
   GWEN_DIRECTORY *d;
   int rv;
   char buffer[256];
@@ -577,20 +605,21 @@ int GWEN_Directory_GetMatchingFilesRecursively(const char *folder,
   GWEN_Buffer_AppendString(pbuf, GWEN_DIR_SEPARATOR_S);
   pos=GWEN_Buffer_GetPos(pbuf);
 
-  while(0==GWEN_Directory_Read(d, buffer, sizeof(buffer)-2)) {
+  while (0==GWEN_Directory_Read(d, buffer, sizeof(buffer)-2)) {
     if (strcmp(buffer, ".")!=0 &&
         strcmp(buffer, "..")!=0) {
       struct stat st;
 
       GWEN_Buffer_AppendString(pbuf, buffer);
       if (stat(GWEN_Buffer_GetStart(pbuf), &st)==0) {
-	if (S_ISDIR(st.st_mode))
-	  /* add folders to the folder list */
-	  GWEN_StringList_AppendString(folderList, GWEN_Buffer_GetStart(pbuf), 0, 1);
-	else {
-	  if (mask==NULL || GWEN_Text_ComparePattern(buffer, mask, 0)!=-1)
-	    GWEN_StringList_AppendString(sl, GWEN_Buffer_GetStart(pbuf), 0, 1);
-	}
+        if (S_ISDIR(st.st_mode))
+          /* add folders to the folder list */
+          GWEN_StringList_AppendString(folderList, GWEN_Buffer_GetStart(pbuf), 0, 0);
+        else {
+          if (mask==NULL || GWEN_Text_ComparePattern(buffer, mask, 0)!=-1)
+            /* don't check for duplicates here (i.e. last param =0) */
+            GWEN_StringList_AppendString(sl, GWEN_Buffer_GetStart(pbuf), 0, 0);
+        }
       }
       GWEN_Buffer_Crop(pbuf, 0, pos);
     }
@@ -603,12 +632,12 @@ int GWEN_Directory_GetMatchingFilesRecursively(const char *folder,
     GWEN_STRINGLISTENTRY *se;
 
     se=GWEN_StringList_FirstEntry(folderList);
-    while(se) {
+    while (se) {
       const char *s;
 
       s=GWEN_StringListEntry_Data(se);
       if (s && *s)
-	GWEN_Directory_GetMatchingFilesRecursively(s, sl, mask);
+        GWEN_Directory_GetMatchingFilesRecursively(s, sl, mask);
       se=GWEN_StringListEntry_Next(se);
     }
   }
@@ -620,7 +649,8 @@ int GWEN_Directory_GetMatchingFilesRecursively(const char *folder,
 
 
 
-int GWEN_Directory_GetAbsoluteFolderPath(const char *folder, GWEN_BUFFER *tbuf) {
+int GWEN_Directory_GetAbsoluteFolderPath(const char *folder, GWEN_BUFFER *tbuf)
+{
   char savedPwd[300];
   char dataPwd[300];
 
