@@ -49,7 +49,8 @@ GWEN_INHERIT(GWEN_SYNCIO, GWEN_SYNCIO_FILE)
 
 
 
-GWEN_SYNCIO *GWEN_SyncIo_File_new(const char *path, GWEN_SYNCIO_FILE_CREATIONMODE cm) {
+GWEN_SYNCIO *GWEN_SyncIo_File_new(const char *path, GWEN_SYNCIO_FILE_CREATIONMODE cm)
+{
   GWEN_SYNCIO *sio;
   GWEN_SYNCIO_FILE *xio;
 
@@ -71,7 +72,8 @@ GWEN_SYNCIO *GWEN_SyncIo_File_new(const char *path, GWEN_SYNCIO_FILE_CREATIONMOD
 
 
 
-GWEN_SYNCIO *GWEN_SyncIo_File_fromFd(int fd) {
+GWEN_SYNCIO *GWEN_SyncIo_File_fromFd(int fd)
+{
   GWEN_SYNCIO *sio;
   GWEN_SYNCIO_FILE *xio;
 
@@ -92,7 +94,8 @@ GWEN_SYNCIO *GWEN_SyncIo_File_fromFd(int fd) {
 
 
 
-GWEN_SYNCIO *GWEN_SyncIo_File_fromStdHandle(int fd, const char *hname) {
+GWEN_SYNCIO *GWEN_SyncIo_File_fromStdHandle(int fd, const char *hname)
+{
   GWEN_SYNCIO *sio;
   GWEN_SYNCIO_FILE *xio;
 
@@ -114,19 +117,22 @@ GWEN_SYNCIO *GWEN_SyncIo_File_fromStdHandle(int fd, const char *hname) {
 
 
 
-GWEN_SYNCIO *GWEN_SyncIo_File_fromStdin() {
+GWEN_SYNCIO *GWEN_SyncIo_File_fromStdin(void)
+{
   return GWEN_SyncIo_File_fromStdHandle(fileno(stdin), "stdin");
 }
 
 
 
-GWEN_SYNCIO *GWEN_SyncIo_File_fromStdout() {
+GWEN_SYNCIO *GWEN_SyncIo_File_fromStdout(void)
+{
   return GWEN_SyncIo_File_fromStdHandle(fileno(stdout), "stdout");
 }
 
 
 
-GWEN_SYNCIO *GWEN_SyncIo_File_fromStderr() {
+GWEN_SYNCIO *GWEN_SyncIo_File_fromStderr(void)
+{
   return GWEN_SyncIo_File_fromStdHandle(fileno(stderr), "stderr");
 }
 
@@ -136,7 +142,8 @@ GWEN_SYNCIO *GWEN_SyncIo_File_fromStderr() {
 
 
 
-const char *GWEN_SyncIo_File_GetPath(const GWEN_SYNCIO *sio) {
+const char *GWEN_SyncIo_File_GetPath(const GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_FILE *xio;
 
   assert(sio);
@@ -148,17 +155,19 @@ const char *GWEN_SyncIo_File_GetPath(const GWEN_SYNCIO *sio) {
 
 
 
-void GWENHYWFAR_CB GWEN_SyncIo_File_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB GWEN_SyncIo_File_FreeData(GWEN_UNUSED void *bp, void *p)
+{
   GWEN_SYNCIO_FILE *xio;
 
-  xio=(GWEN_SYNCIO_FILE*) p;
+  xio=(GWEN_SYNCIO_FILE *) p;
   free(xio->path);
   GWEN_FREE_OBJECT(xio);
 }
 
 
 
-int GWENHYWFAR_CB GWEN_SyncIo_File_Connect(GWEN_SYNCIO *sio) {
+int GWENHYWFAR_CB GWEN_SyncIo_File_Connect(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_FILE *xio;
   int fd;
   uint32_t flags;
@@ -220,7 +229,7 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Connect(GWEN_SYNCIO *sio) {
     mode|=S_IXOTH;
 #endif
 
-  switch(xio->creationMode) {
+  switch (xio->creationMode) {
   case GWEN_SyncIo_File_CreationMode_OpenExisting:
     fd=open(xio->path, acc);
     break;
@@ -244,11 +253,15 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Connect(GWEN_SYNCIO *sio) {
 
   if (fd==-1) {
     DBG_ERROR(GWEN_LOGDOMAIN, "open(%s, %d): %s", xio->path, xio->creationMode, strerror(errno));
-    switch(errno) {
-    case EEXIST: return GWEN_ERROR_FOUND;
-    case EACCES: return GWEN_ERROR_PERMISSIONS;
-    case ENOENT: return GWEN_ERROR_NOT_FOUND;
-    default:     return GWEN_ERROR_IO;
+    switch (errno) {
+    case EEXIST:
+      return GWEN_ERROR_FOUND;
+    case EACCES:
+      return GWEN_ERROR_PERMISSIONS;
+    case ENOENT:
+      return GWEN_ERROR_NOT_FOUND;
+    default:
+      return GWEN_ERROR_IO;
     }
   }
 
@@ -260,7 +273,8 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Connect(GWEN_SYNCIO *sio) {
 
 
 
-int GWENHYWFAR_CB GWEN_SyncIo_File_Disconnect(GWEN_SYNCIO *sio) {
+int GWENHYWFAR_CB GWEN_SyncIo_File_Disconnect(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_FILE *xio;
   int rv=0;
 
@@ -276,13 +290,16 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Disconnect(GWEN_SYNCIO *sio) {
   if (!(GWEN_SyncIo_GetFlags(sio) & GWEN_SYNCIO_FLAGS_DONTCLOSE)) {
     do {
       rv=close(xio->fd);
-    } while (rv==-1 && errno==EINTR);
+    }
+    while (rv==-1 && errno==EINTR);
 
     if (rv==-1) {
       DBG_ERROR(GWEN_LOGDOMAIN, "close(%s): %s", xio->path, strerror(errno));
-      switch(errno) {
-      case ENOSPC: return GWEN_ERROR_MEMORY_FULL;
-      default:     return GWEN_ERROR_IO;
+      switch (errno) {
+      case ENOSPC:
+        return GWEN_ERROR_MEMORY_FULL;
+      default:
+        return GWEN_ERROR_IO;
       }
     }
   }
@@ -296,8 +313,9 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Disconnect(GWEN_SYNCIO *sio) {
 
 
 int GWENHYWFAR_CB GWEN_SyncIo_File_Read(GWEN_SYNCIO *sio,
-					uint8_t *buffer,
-					uint32_t size) {
+                                        uint8_t *buffer,
+                                        uint32_t size)
+{
   GWEN_SYNCIO_FILE *xio;
   ssize_t rv;
 
@@ -311,13 +329,15 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Read(GWEN_SYNCIO *sio,
   }
 
   if (GWEN_SyncIo_GetStatus(sio) != GWEN_SyncIo_Status_Connected) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "GWEN_SYNCIO of file (%s) not connected; did you forget to call GWEN_SyncIo_Connect()?", xio->path);
+    DBG_ERROR(GWEN_LOGDOMAIN, "GWEN_SYNCIO of file (%s) not connected; did you forget to call GWEN_SyncIo_Connect()?",
+              xio->path);
     return GWEN_ERROR_NOT_OPEN;
   }
 
   do {
     rv=read(xio->fd, buffer, size);
-  } while (rv==-1 && errno==EINTR);
+  }
+  while (rv==-1 && errno==EINTR);
 
   if (rv==-1) {
     DBG_ERROR(GWEN_LOGDOMAIN, "read(%s, %lu): %s", xio->path, (long unsigned int) size, strerror(errno));
@@ -330,8 +350,9 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Read(GWEN_SYNCIO *sio,
 
 
 int GWENHYWFAR_CB GWEN_SyncIo_File_Write(GWEN_SYNCIO *sio,
-					 const uint8_t *buffer,
-					 uint32_t size) {
+                                         const uint8_t *buffer,
+                                         uint32_t size)
+{
   GWEN_SYNCIO_FILE *xio;
   ssize_t rv;
 
@@ -346,13 +367,16 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Write(GWEN_SYNCIO *sio,
 
   do {
     rv=write(xio->fd, buffer, size);
-  } while (rv==-1 && errno==EINTR);
+  }
+  while (rv==-1 && errno==EINTR);
 
   if (rv==-1) {
     DBG_ERROR(GWEN_LOGDOMAIN, "write(%d, %s, %lu): %s", xio->fd, xio->path, (long unsigned int) size, strerror(errno));
-    switch(errno) {
-    case ENOSPC: return GWEN_ERROR_MEMORY_FULL;
-    default:     return GWEN_ERROR_IO;
+    switch (errno) {
+    case ENOSPC:
+      return GWEN_ERROR_MEMORY_FULL;
+    default:
+      return GWEN_ERROR_IO;
     }
   }
 
@@ -361,7 +385,8 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Write(GWEN_SYNCIO *sio,
 
 
 
-int64_t GWEN_SyncIo_File_Seek(GWEN_SYNCIO *sio, int64_t pos, GWEN_SYNCIO_FILE_WHENCE whence) {
+int64_t GWEN_SyncIo_File_Seek(GWEN_SYNCIO *sio, int64_t pos, GWEN_SYNCIO_FILE_WHENCE whence)
+{
   GWEN_SYNCIO_FILE *xio;
   off_t rv;
   int w;
@@ -370,10 +395,16 @@ int64_t GWEN_SyncIo_File_Seek(GWEN_SYNCIO *sio, int64_t pos, GWEN_SYNCIO_FILE_WH
   xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_FILE, sio);
   assert(xio);
 
-  switch(whence) {
-  case GWEN_SyncIo_File_Whence_Set:     w=SEEK_SET; break;
-  case GWEN_SyncIo_File_Whence_Current: w=SEEK_CUR; break;
-  case GWEN_SyncIo_File_Whence_End:     w=SEEK_END; break;
+  switch (whence) {
+  case GWEN_SyncIo_File_Whence_Set:
+    w=SEEK_SET;
+    break;
+  case GWEN_SyncIo_File_Whence_Current:
+    w=SEEK_CUR;
+    break;
+  case GWEN_SyncIo_File_Whence_End:
+    w=SEEK_END;
+    break;
   default:
     DBG_ERROR(GWEN_LOGDOMAIN, "Invalid seek mode (%d)", whence);
     return GWEN_ERROR_INVALID;
@@ -381,8 +412,8 @@ int64_t GWEN_SyncIo_File_Seek(GWEN_SYNCIO *sio, int64_t pos, GWEN_SYNCIO_FILE_WH
 
   rv=lseek(xio->fd, pos, w);
   if (rv==-1) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "lseek(%s, %lli): %s",
-	      xio->path, (long long int) pos, strerror(errno));
+    DBG_ERROR(GWEN_LOGDOMAIN, "lseek(%s, %" PRIi64 "): %s",
+              xio->path, (int64_t) pos, strerror(errno));
     return GWEN_ERROR_IO;
   }
   return rv;
