@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Tue Sep 09 2003
- copyright   : (C) 2003 by Martin Preuss
+ copyright   : (C) 2019 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -39,12 +36,29 @@
 
 
 
+/* ------------------------------------------------------------------------------------------------
+ * forward declarations
+ * ------------------------------------------------------------------------------------------------
+ */
+
+
+static void *GWEN_Path_AppendPathElement(const char *entry, void *data, unsigned int flags);
+
+
+/* ------------------------------------------------------------------------------------------------
+ * implementations
+ * ------------------------------------------------------------------------------------------------
+ */
+
+
+
+
 void *GWEN_Path_Handle(const char *path,
                        void *data,
                        uint32_t flags,
-                       GWEN_PATHHANDLERPTR elementFunction) {
+                       GWEN_PATHHANDLERPTR elementFunction)
+{
   GWEN_BUFFER *buf1;
-  int i;
   unsigned int origflags;
   int startAtRoot;
 
@@ -68,11 +82,10 @@ void *GWEN_Path_Handle(const char *path,
     GWEN_Buffer_Reset(buf1);
 
     flags=origflags &
-      ~GWEN_PATH_FLAGS_INTERNAL &
-      ~GWEN_PATH_FLAGS_VARIABLE;
+          ~GWEN_PATH_FLAGS_INTERNAL &
+          ~GWEN_PATH_FLAGS_VARIABLE;
 
     /* copy element into buffer */
-    i=0;
     if (startAtRoot) {
       GWEN_Buffer_AppendByte(buf1, '/');
       flags|=GWEN_PATH_FLAGS_ROOT;
@@ -193,9 +206,9 @@ void *GWEN_Path_Handle(const char *path,
 void *GWEN_Path_HandleWithIdx(const char *path,
                               void *data,
                               uint32_t flags,
-                              GWEN_PATHIDXHANDLERPTR elementFunction) {
+                              GWEN_PATHIDXHANDLERPTR elementFunction)
+{
   GWEN_BUFFER *buf1;
-  int i;
   unsigned int origflags;
   int startAtRoot;
 
@@ -216,18 +229,16 @@ void *GWEN_Path_HandleWithIdx(const char *path,
   } /* while */
 
   while (*path) {
-    char *p;
     int idx;
 
     idx=0;
     GWEN_Buffer_Reset(buf1);
 
     flags=origflags &
-      ~GWEN_PATH_FLAGS_INTERNAL &
-      ~GWEN_PATH_FLAGS_VARIABLE;
+          ~GWEN_PATH_FLAGS_INTERNAL &
+          ~GWEN_PATH_FLAGS_VARIABLE;
 
     /* copy element into buffer */
-    i=0;
     if (startAtRoot) {
       GWEN_Buffer_AppendByte(buf1, '/');
       flags|=GWEN_PATH_FLAGS_ROOT;
@@ -237,6 +248,8 @@ void *GWEN_Path_HandleWithIdx(const char *path,
 
     /* now buffer contains the element, check for index */
     if (!(flags & GWEN_PATH_FLAGS_NO_IDX)) {
+      char *p;
+
       p=strchr(GWEN_Buffer_GetStart(buf1), '[');
       if (p) {
         char *p2;
@@ -372,12 +385,11 @@ void *GWEN_Path_HandleWithIdx(const char *path,
 
 
 
-void *GWEN_Path_AppendPathElement(const char *entry,
-                                  void *data,
-                                  unsigned int flags){
+void *GWEN_Path_AppendPathElement(const char *entry, void *data, unsigned int flags)
+{
   GWEN_BUFFER *ebuf;
 
-  ebuf=(GWEN_BUFFER*)data;
+  ebuf=(GWEN_BUFFER *)data;
 
   GWEN_Buffer_AppendString(ebuf, entry);
   if (!(flags & GWEN_PATH_FLAGS_LAST) ||
@@ -392,7 +404,8 @@ void *GWEN_Path_AppendPathElement(const char *entry,
 
 int GWEN_Path_Convert(const char *path,
                       GWEN_BUFFER *buffer,
-                      uint32_t flags) {
+                      uint32_t flags)
+{
   void *p;
 
   p=GWEN_Path_Handle(path,
