@@ -170,8 +170,8 @@ int GWEN_SyncIo_WriteChar(GWEN_SYNCIO *sio, char s);
 
 GWENHYWFAR_API
 int GWEN_SyncIo_Helper_ReadFileToStringList(const char *fname,
-    int maxLines,
-    GWEN_STRINGLIST *sl);
+                                            int maxLines,
+                                            GWEN_STRINGLIST *sl);
 
 
 /**
@@ -198,6 +198,19 @@ GWENHYWFAR_API
 int GWEN_SyncIo_Helper_ReadFile(const char *fName, GWEN_BUFFER *dbuf);
 
 
+/**
+ * Writes a whole file from the given buffer
+ *
+ * @return number of bytes actually written (or error code if negative value)
+ * @param fName name of the file to load
+ * @param ptrSource pointer to the data to write
+ * @param lenSource size of the data to write
+ */
+GWENHYWFAR_API
+int GWEN_SyncIo_Helper_WriteFile(const char *fName, const uint8_t *ptrSource, uint64_t lenSource);
+
+
+
 
 /** @name Declarations for Virtual Functions
  *
@@ -209,14 +222,14 @@ typedef GWENHYWFAR_CB int (*GWEN_SYNCIO_FLUSH_FN)(GWEN_SYNCIO *sio);
 
 
 typedef GWENHYWFAR_CB int (*GWEN_SYNCIO_READ_FN)(GWEN_SYNCIO *sio,
-    uint8_t *buffer,
-    uint32_t size);
+                                                 uint8_t *buffer,
+                                                 uint32_t size);
 
 
 
 typedef GWENHYWFAR_CB int (*GWEN_SYNCIO_WRITE_FN)(GWEN_SYNCIO *sio,
-    const uint8_t *buffer,
-    uint32_t size);
+                                                  const uint8_t *buffer,
+                                                  uint32_t size);
 /*@}*/
 
 
