@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Wed Jul 01 2009
-    copyright   : (C) 2009 by Martin Preuss
+    copyright   : (C) 2018 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -25,41 +25,50 @@ GWEN_LIST2_FUNCTION_DEFS(TYPEMAKER2_TYPE, Typemaker2_Type)
 
 
 /* don't forget to add new flags to tm_util.c ! */
-#define TYPEMAKER2_FLAGS_OWN               0x00000001
-#define TYPEMAKER2_FLAGS_VOLATILE          0x00000002
-#define TYPEMAKER2_FLAGS_CONST             0x00000004
-#define TYPEMAKER2_FLAGS_STATIC            0x00000008
-#define TYPEMAKER2_FLAGS_DUP               0x00000010
-#define TYPEMAKER2_FLAGS_NODUP             0x00000020
-#define TYPEMAKER2_FLAGS_ATTRIBUTE         0x00000040
-#define TYPEMAKER2_FLAGS_ENUM              0x00000080
-#define TYPEMAKER2_FLAGS_DEFINE            0x00000100
-#define TYPEMAKER2_FLAGS_ASSIGN            0x00000200
-#define TYPEMAKER2_FLAGS_OMIT              0x00000400
-#define TYPEMAKER2_FLAGS_COPY              0x00000800
-#define TYPEMAKER2_FLAGS_NOCOPY            0x00001000
-#define TYPEMAKER2_FLAGS_SORTBYMEMBER      0x00002000
-#define TYPEMAKER2_FLAGS_NOCONSTOBJECT     0x00004000
 
 /** special value which is used to overwrite flags from extended types */
-#define TYPEMAKER2_FLAGS_NONE              0x00008000
+#define TYPEMAKER2_FLAGS_NONE                  0x00000001
+#define TYPEMAKER2_FLAGS_OWN                   0x00000002
+#define TYPEMAKER2_FLAGS_VOLATILE              0x00000004
+#define TYPEMAKER2_FLAGS_CONST                 0x00000008
+#define TYPEMAKER2_FLAGS_STATIC                0x00000010
+#define TYPEMAKER2_FLAGS_DUP                   0x00000020
+#define TYPEMAKER2_FLAGS_NODUP                 0x00000040
+#define TYPEMAKER2_FLAGS_ATTRIBUTE             0x00000080
+#define TYPEMAKER2_FLAGS_ENUM                  0x00000100
+#define TYPEMAKER2_FLAGS_DEFINE                0x00000200
+#define TYPEMAKER2_FLAGS_ASSIGN                0x00000400
+#define TYPEMAKER2_FLAGS_OMIT                  0x00000800
+#define TYPEMAKER2_FLAGS_COPY                  0x00001000
+#define TYPEMAKER2_FLAGS_NOCOPY                0x00002000
+#define TYPEMAKER2_FLAGS_SORTBYMEMBER          0x00004000
+#define TYPEMAKER2_FLAGS_NOCONSTOBJECT         0x00008000
+#define TYPEMAKER2_FLAGS_WITH_GETBYMEMBER      0x00010000
+#define TYPEMAKER2_FLAGS_WITH_HASH             0x00020000
+#define TYPEMAKER2_FLAGS_WITH_HASHNUM          0x00040000
+#define TYPEMAKER2_FLAGS_WITH_FLAGS            0x00080000
+#define TYPEMAKER2_FLAGS_GWEN_CB               0x00100000
 
-#define TYPEMAKER2_FLAGS_WITH_DB           0x00010000
-#define TYPEMAKER2_FLAGS_WITH_XML          0x00020000
-#define TYPEMAKER2_FLAGS_WITH_OBJECT       0x00040000
-#define TYPEMAKER2_FLAGS_WITH_LIST1        0x00080000
-#define TYPEMAKER2_FLAGS_WITH_LIST2        0x00100000
-#define TYPEMAKER2_FLAGS_WITH_INHERIT      0x00200000
-#define TYPEMAKER2_FLAGS_WITH_IDMAP        0x00400000
-#define TYPEMAKER2_FLAGS_WITH_GETBYMEMBER  0x00800000
-#define TYPEMAKER2_FLAGS_WITH_TREE         0x01000000
-#define TYPEMAKER2_FLAGS_WITH_HASH         0x02000000
-#define TYPEMAKER2_FLAGS_WITH_REFCOUNT     0x04000000
-#define TYPEMAKER2_FLAGS_WITH_FLAGS        0x08000000
-#define TYPEMAKER2_FLAGS_WITH_HASHNUM      0x10000000
-#define TYPEMAKER2_FLAGS_WITH_SIGNALS      0x20000000
-#define TYPEMAKER2_FLAGS_WITH_SLOTS        0x40000000
-#define TYPEMAKER2_FLAGS_WITH_CACHEFNS     0x80000000
+
+#define TYPEMAKER2_TYPEFLAGS_WITH_DB           0x00000001
+#define TYPEMAKER2_TYPEFLAGS_WITH_XML          0x00000002
+#define TYPEMAKER2_TYPEFLAGS_WITH_OBJECT       0x00000004
+#define TYPEMAKER2_TYPEFLAGS_WITH_LIST1        0x00000008
+#define TYPEMAKER2_TYPEFLAGS_WITH_LIST2        0x00000010
+#define TYPEMAKER2_TYPEFLAGS_WITH_INHERIT      0x00000020
+#define TYPEMAKER2_TYPEFLAGS_WITH_IDMAP        0x00000040
+#define TYPEMAKER2_TYPEFLAGS_WITH_TREE         0x00000080
+#define TYPEMAKER2_TYPEFLAGS_WITH_REFCOUNT     0x00000100
+#define TYPEMAKER2_TYPEFLAGS_WITH_SIGNALS      0x00000800
+#define TYPEMAKER2_TYPEFLAGS_WITH_SLOTS        0x00001000
+#define TYPEMAKER2_TYPEFLAGS_WITH_CACHEFNS     0x00002000
+#define TYPEMAKER2_TYPEFLAGS_DUP               0x00004000
+#define TYPEMAKER2_TYPEFLAGS_NODUP             0x00008000
+#define TYPEMAKER2_TYPEFLAGS_COPY              0x00010000
+#define TYPEMAKER2_TYPEFLAGS_NOCOPY            0x00020000
+#define TYPEMAKER2_TYPEFLAGS_WITH_HASH         0x00040000
+#define TYPEMAKER2_TYPEFLAGS_WITH_CONSTLIST2   0x00080000
+#define TYPEMAKER2_TYPEFLAGS_WITH_TREE2        0x00100000
 
 
 
@@ -90,6 +99,7 @@ enum {
 #include "tm_virtualfn.h"
 #include "tm_signal.h"
 #include "tm_slot.h"
+#include "tm_group.h"
 
 
 
@@ -108,7 +118,6 @@ void Typemaker2_Type_SetExtends(TYPEMAKER2_TYPE *ty, const char *s);
 const char *Typemaker2_Type_GetBaseType(const TYPEMAKER2_TYPE *ty);
 void Typemaker2_Type_SetBaseType(TYPEMAKER2_TYPE *ty, const char *s);
 
-
 int Typemaker2_Type_GetType(const TYPEMAKER2_TYPE *ty);
 void Typemaker2_Type_SetType(TYPEMAKER2_TYPE *ty, int i);
 
@@ -176,7 +185,7 @@ TYPEMAKER2_INLINE_LIST *Typemaker2_Type_GetInlines(const TYPEMAKER2_TYPE *ty);
 TYPEMAKER2_VIRTUALFN_LIST *Typemaker2_Type_GetVirtualFns(const TYPEMAKER2_TYPE *ty);
 TYPEMAKER2_SIGNAL_LIST *Typemaker2_Type_GetSignals(const TYPEMAKER2_TYPE *ty);
 TYPEMAKER2_SLOT_LIST *Typemaker2_Type_GetSlots(const TYPEMAKER2_TYPE *ty);
-
+TYPEMAKER2_GROUP_TREE *Typemaker2_Type_GetGroupTree(const TYPEMAKER2_TYPE *ty);
 
 int Typemaker2_Type_GetNonVolatileMemberCount(const TYPEMAKER2_TYPE *ty);
 void Typemaker2_Type_SetNonVolatileMemberCount(TYPEMAKER2_TYPE *ty, int i);
@@ -198,7 +207,7 @@ void Typemaker2_Type_SetFieldCountId(TYPEMAKER2_TYPE *ty, const char *s);
 TYPEMAKER2_ENUM *Typemaker2_Type_FindEnum(TYPEMAKER2_TYPE *ty, const char *s);
 TYPEMAKER2_CODE *Typemaker2_Type_FindCodeForMember(const TYPEMAKER2_TYPE *ty,
                                                    const TYPEMAKER2_MEMBER *tm,
-						   const char *id);
+                                                   const char *id);
 
 
 int Typemaker2_Type_readXml(TYPEMAKER2_TYPE *ty, GWEN_XMLNODE *node, const char *wantedLang);
